Class Public.ArrowFileUploadResponse

  • All Implemented Interfaces:
    Public.ArrowFileUploadResponseOrBuilder, com.google.protobuf.Message, com.google.protobuf.MessageLite, com.google.protobuf.MessageLiteOrBuilder, com.google.protobuf.MessageOrBuilder, Serializable
    Enclosing class:
    Public

    public static final class Public.ArrowFileUploadResponse
    extends com.google.protobuf.GeneratedMessageV3
    implements Public.ArrowFileUploadResponseOrBuilder
     ArrowFileUploadResponse is the response body for the ArrowFileUpload receiver endpoint.
     
    Protobuf type public.ArrowFileUploadResponse
    See Also:
    Serialized Form
    • Field Detail

      • REAL_TIME_INGESTION_URI_FIELD_NUMBER

        public static final int REAL_TIME_INGESTION_URI_FIELD_NUMBER
        See Also:
        Constant Field Values
    • Method Detail

      • newInstance

        protected Object newInstance​(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)
        Overrides:
        newInstance in class com.google.protobuf.GeneratedMessageV3
      • getUnknownFields

        public final com.google.protobuf.UnknownFieldSet getUnknownFields()
        Specified by:
        getUnknownFields in interface com.google.protobuf.MessageOrBuilder
        Overrides:
        getUnknownFields in class com.google.protobuf.GeneratedMessageV3
      • getDescriptor

        public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
      • internalGetFieldAccessorTable

        protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()
        Specified by:
        internalGetFieldAccessorTable in class com.google.protobuf.GeneratedMessageV3
      • getError

        public String getError()
         error field is set if any error was encountered during the file upload request. If request was successful this field
         is an empty string
         
        string error = 1;
        Specified by:
        getError in interface Public.ArrowFileUploadResponseOrBuilder
        Returns:
        The error.
      • getErrorBytes

        public com.google.protobuf.ByteString getErrorBytes()
         error field is set if any error was encountered during the file upload request. If request was successful this field
         is an empty string
         
        string error = 1;
        Specified by:
        getErrorBytes in interface Public.ArrowFileUploadResponseOrBuilder
        Returns:
        The bytes for error.
      • getRealTimeIngestionUri

        public String getRealTimeIngestionUri()
         the URI to the real time ingestion page that will show real time ingestion stats on the records sent in via the file upload
         this field is empty if an error occurred during the request.
         
        string real_time_ingestion_uri = 2;
        Specified by:
        getRealTimeIngestionUri in interface Public.ArrowFileUploadResponseOrBuilder
        Returns:
        The realTimeIngestionUri.
      • getRealTimeIngestionUriBytes

        public com.google.protobuf.ByteString getRealTimeIngestionUriBytes()
         the URI to the real time ingestion page that will show real time ingestion stats on the records sent in via the file upload
         this field is empty if an error occurred during the request.
         
        string real_time_ingestion_uri = 2;
        Specified by:
        getRealTimeIngestionUriBytes in interface Public.ArrowFileUploadResponseOrBuilder
        Returns:
        The bytes for realTimeIngestionUri.
      • isInitialized

        public final boolean isInitialized()
        Specified by:
        isInitialized in interface com.google.protobuf.MessageLiteOrBuilder
        Overrides:
        isInitialized in class com.google.protobuf.GeneratedMessageV3
      • writeTo

        public void writeTo​(com.google.protobuf.CodedOutputStream output)
                     throws IOException
        Specified by:
        writeTo in interface com.google.protobuf.MessageLite
        Overrides:
        writeTo in class com.google.protobuf.GeneratedMessageV3
        Throws:
        IOException
      • getSerializedSize

        public int getSerializedSize()
        Specified by:
        getSerializedSize in interface com.google.protobuf.MessageLite
        Overrides:
        getSerializedSize in class com.google.protobuf.GeneratedMessageV3
      • equals

        public boolean equals​(Object obj)
        Specified by:
        equals in interface com.google.protobuf.Message
        Overrides:
        equals in class com.google.protobuf.AbstractMessage
      • hashCode

        public int hashCode()
        Specified by:
        hashCode in interface com.google.protobuf.Message
        Overrides:
        hashCode in class com.google.protobuf.AbstractMessage
      • parseFrom

        public static Public.ArrowFileUploadResponse parseFrom​(ByteBuffer data)
                                                        throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Public.ArrowFileUploadResponse parseFrom​(ByteBuffer data,
                                                               com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                                        throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Public.ArrowFileUploadResponse parseFrom​(com.google.protobuf.ByteString data)
                                                        throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Public.ArrowFileUploadResponse parseFrom​(com.google.protobuf.ByteString data,
                                                               com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                                        throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Public.ArrowFileUploadResponse parseFrom​(byte[] data)
                                                        throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Public.ArrowFileUploadResponse parseFrom​(byte[] data,
                                                               com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                                        throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • newBuilderForType

        public Public.ArrowFileUploadResponse.Builder newBuilderForType()
        Specified by:
        newBuilderForType in interface com.google.protobuf.Message
        Specified by:
        newBuilderForType in interface com.google.protobuf.MessageLite
      • toBuilder

        public Public.ArrowFileUploadResponse.Builder toBuilder()
        Specified by:
        toBuilder in interface com.google.protobuf.Message
        Specified by:
        toBuilder in interface com.google.protobuf.MessageLite
      • newBuilderForType

        protected Public.ArrowFileUploadResponse.Builder newBuilderForType​(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)
        Specified by:
        newBuilderForType in class com.google.protobuf.GeneratedMessageV3
      • getParserForType

        public com.google.protobuf.Parser<Public.ArrowFileUploadResponse> getParserForType()
        Specified by:
        getParserForType in interface com.google.protobuf.Message
        Specified by:
        getParserForType in interface com.google.protobuf.MessageLite
        Overrides:
        getParserForType in class com.google.protobuf.GeneratedMessageV3
      • getDefaultInstanceForType

        public Public.ArrowFileUploadResponse getDefaultInstanceForType()
        Specified by:
        getDefaultInstanceForType in interface com.google.protobuf.MessageLiteOrBuilder
        Specified by:
        getDefaultInstanceForType in interface com.google.protobuf.MessageOrBuilder