Package com.arize.protocol
Class Public.DatasetCreateConstants
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite
-
- com.google.protobuf.AbstractMessage
-
- com.google.protobuf.GeneratedMessageV3
-
- com.arize.protocol.Public.DatasetCreateConstants
-
- All Implemented Interfaces:
Public.DatasetCreateConstantsOrBuilder,com.google.protobuf.Message,com.google.protobuf.MessageLite,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,Serializable
- Enclosing class:
- Public
public static final class Public.DatasetCreateConstants extends com.google.protobuf.GeneratedMessageV3 implements Public.DatasetCreateConstantsOrBuilder
Protobuf typepublic.DatasetCreateConstants- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classPublic.DatasetCreateConstants.BuilderProtobuf typepublic.DatasetCreateConstants-
Nested classes/interfaces inherited from class com.google.protobuf.GeneratedMessageV3
com.google.protobuf.GeneratedMessageV3.BuilderParent, com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>,BuilderT extends com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT,BuilderT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessageOrBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.FieldAccessorTable, com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter
-
-
Field Summary
Fields Modifier and Type Field Description static intCOLUMN_MAPPING_FIELD_NUMBERstatic intCREATED_BY_USER_ID_FIELD_NUMBERstatic intNAME_FIELD_NUMBER
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Deprecated Methods Modifier and Type Method Description booleancontainsColumnMapping(String key)Optionally can be specified to create a corresponding entry in the dataset_column_mapping_configs table.booleanequals(Object obj)Map<String,String>getColumnMapping()Deprecated.intgetColumnMappingCount()Optionally can be specified to create a corresponding entry in the dataset_column_mapping_configs table.Map<String,String>getColumnMappingMap()Optionally can be specified to create a corresponding entry in the dataset_column_mapping_configs table.StringgetColumnMappingOrDefault(String key, String defaultValue)Optionally can be specified to create a corresponding entry in the dataset_column_mapping_configs table.StringgetColumnMappingOrThrow(String key)Optionally can be specified to create a corresponding entry in the dataset_column_mapping_configs table.longgetCreatedByUserId()int64 created_by_user_id = 2;static Public.DatasetCreateConstantsgetDefaultInstance()Public.DatasetCreateConstantsgetDefaultInstanceForType()static com.google.protobuf.Descriptors.DescriptorgetDescriptor()StringgetName()string name = 1;com.google.protobuf.ByteStringgetNameBytes()string name = 1;com.google.protobuf.Parser<Public.DatasetCreateConstants>getParserForType()intgetSerializedSize()com.google.protobuf.UnknownFieldSetgetUnknownFields()inthashCode()protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTableinternalGetFieldAccessorTable()protected com.google.protobuf.MapFieldinternalGetMapField(int number)booleanisInitialized()static Public.DatasetCreateConstants.BuildernewBuilder()static Public.DatasetCreateConstants.BuildernewBuilder(Public.DatasetCreateConstants prototype)Public.DatasetCreateConstants.BuildernewBuilderForType()protected Public.DatasetCreateConstants.BuildernewBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)protected ObjectnewInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)static Public.DatasetCreateConstantsparseDelimitedFrom(InputStream input)static Public.DatasetCreateConstantsparseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.DatasetCreateConstantsparseFrom(byte[] data)static Public.DatasetCreateConstantsparseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.DatasetCreateConstantsparseFrom(com.google.protobuf.ByteString data)static Public.DatasetCreateConstantsparseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.DatasetCreateConstantsparseFrom(com.google.protobuf.CodedInputStream input)static Public.DatasetCreateConstantsparseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.DatasetCreateConstantsparseFrom(InputStream input)static Public.DatasetCreateConstantsparseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.DatasetCreateConstantsparseFrom(ByteBuffer data)static Public.DatasetCreateConstantsparseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static com.google.protobuf.Parser<Public.DatasetCreateConstants>parser()Public.DatasetCreateConstants.BuildertoBuilder()voidwriteTo(com.google.protobuf.CodedOutputStream output)-
Methods inherited from class com.google.protobuf.GeneratedMessageV3
canUseUnsafe, computeStringSize, computeStringSizeNoTag, emptyBooleanList, emptyDoubleList, emptyFloatList, emptyIntList, emptyList, emptyLongList, getAllFields, getDescriptorForType, getField, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, hasField, hasOneof, internalGetMapFieldReflection, isStringEmpty, makeExtensionsImmutable, makeMutableCopy, makeMutableCopy, mergeFromAndMakeImmutableInternal, mutableCopy, mutableCopy, mutableCopy, mutableCopy, mutableCopy, newBooleanList, newBuilderForType, newDoubleList, newFloatList, newIntList, newLongList, parseDelimitedWithIOException, parseDelimitedWithIOException, parseUnknownField, parseUnknownFieldProto3, parseWithIOException, parseWithIOException, parseWithIOException, parseWithIOException, serializeBooleanMapTo, serializeIntegerMapTo, serializeLongMapTo, serializeStringMapTo, writeReplace, writeString, writeStringNoTag
-
Methods inherited from class com.google.protobuf.AbstractMessage
findInitializationErrors, getInitializationErrorString, hashBoolean, hashEnum, hashEnumList, hashFields, hashLong, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite
addAll, addAll, checkByteStringIsUtf8, toByteArray, toByteString, writeDelimitedTo, writeTo
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
-
-
-
Field Detail
-
NAME_FIELD_NUMBER
public static final int NAME_FIELD_NUMBER
- See Also:
- Constant Field Values
-
CREATED_BY_USER_ID_FIELD_NUMBER
public static final int CREATED_BY_USER_ID_FIELD_NUMBER
- See Also:
- Constant Field Values
-
COLUMN_MAPPING_FIELD_NUMBER
public static final int COLUMN_MAPPING_FIELD_NUMBER
- See Also:
- Constant Field Values
-
-
Method Detail
-
newInstance
protected Object newInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)
- Overrides:
newInstancein classcom.google.protobuf.GeneratedMessageV3
-
getUnknownFields
public final com.google.protobuf.UnknownFieldSet getUnknownFields()
- Specified by:
getUnknownFieldsin interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getUnknownFieldsin classcom.google.protobuf.GeneratedMessageV3
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetMapField
protected com.google.protobuf.MapField internalGetMapField(int number)
- Overrides:
internalGetMapFieldin classcom.google.protobuf.GeneratedMessageV3
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessageV3
-
getName
public String getName()
string name = 1;- Specified by:
getNamein interfacePublic.DatasetCreateConstantsOrBuilder- Returns:
- The name.
-
getNameBytes
public com.google.protobuf.ByteString getNameBytes()
string name = 1;- Specified by:
getNameBytesin interfacePublic.DatasetCreateConstantsOrBuilder- Returns:
- The bytes for name.
-
getCreatedByUserId
public long getCreatedByUserId()
int64 created_by_user_id = 2;- Specified by:
getCreatedByUserIdin interfacePublic.DatasetCreateConstantsOrBuilder- Returns:
- The createdByUserId.
-
getColumnMappingCount
public int getColumnMappingCount()
Description copied from interface:Public.DatasetCreateConstantsOrBuilderOptionally can be specified to create a corresponding entry in the dataset_column_mapping_configs table.
map<string, string> column_mapping = 3;- Specified by:
getColumnMappingCountin interfacePublic.DatasetCreateConstantsOrBuilder
-
containsColumnMapping
public boolean containsColumnMapping(String key)
Optionally can be specified to create a corresponding entry in the dataset_column_mapping_configs table.
map<string, string> column_mapping = 3;- Specified by:
containsColumnMappingin interfacePublic.DatasetCreateConstantsOrBuilder
-
getColumnMapping
@Deprecated public Map<String,String> getColumnMapping()
Deprecated.UsegetColumnMappingMap()instead.- Specified by:
getColumnMappingin interfacePublic.DatasetCreateConstantsOrBuilder
-
getColumnMappingMap
public Map<String,String> getColumnMappingMap()
Optionally can be specified to create a corresponding entry in the dataset_column_mapping_configs table.
map<string, string> column_mapping = 3;- Specified by:
getColumnMappingMapin interfacePublic.DatasetCreateConstantsOrBuilder
-
getColumnMappingOrDefault
public String getColumnMappingOrDefault(String key, String defaultValue)
Optionally can be specified to create a corresponding entry in the dataset_column_mapping_configs table.
map<string, string> column_mapping = 3;- Specified by:
getColumnMappingOrDefaultin interfacePublic.DatasetCreateConstantsOrBuilder
-
getColumnMappingOrThrow
public String getColumnMappingOrThrow(String key)
Optionally can be specified to create a corresponding entry in the dataset_column_mapping_configs table.
map<string, string> column_mapping = 3;- Specified by:
getColumnMappingOrThrowin interfacePublic.DatasetCreateConstantsOrBuilder
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessageV3
-
writeTo
public void writeTo(com.google.protobuf.CodedOutputStream output) throws IOException- Specified by:
writeToin interfacecom.google.protobuf.MessageLite- Overrides:
writeToin classcom.google.protobuf.GeneratedMessageV3- Throws:
IOException
-
getSerializedSize
public int getSerializedSize()
- Specified by:
getSerializedSizein interfacecom.google.protobuf.MessageLite- Overrides:
getSerializedSizein classcom.google.protobuf.GeneratedMessageV3
-
equals
public boolean equals(Object obj)
- Specified by:
equalsin interfacecom.google.protobuf.Message- Overrides:
equalsin classcom.google.protobuf.AbstractMessage
-
hashCode
public int hashCode()
- Specified by:
hashCodein interfacecom.google.protobuf.Message- Overrides:
hashCodein classcom.google.protobuf.AbstractMessage
-
parseFrom
public static Public.DatasetCreateConstants parseFrom(ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.DatasetCreateConstants parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.DatasetCreateConstants parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.DatasetCreateConstants parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.DatasetCreateConstants parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.DatasetCreateConstants parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.DatasetCreateConstants parseFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.DatasetCreateConstants parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.DatasetCreateConstants parseDelimitedFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.DatasetCreateConstants parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.DatasetCreateConstants parseFrom(com.google.protobuf.CodedInputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.DatasetCreateConstants parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
newBuilderForType
public Public.DatasetCreateConstants.Builder newBuilderForType()
- Specified by:
newBuilderForTypein interfacecom.google.protobuf.Message- Specified by:
newBuilderForTypein interfacecom.google.protobuf.MessageLite
-
newBuilder
public static Public.DatasetCreateConstants.Builder newBuilder()
-
newBuilder
public static Public.DatasetCreateConstants.Builder newBuilder(Public.DatasetCreateConstants prototype)
-
toBuilder
public Public.DatasetCreateConstants.Builder toBuilder()
- Specified by:
toBuilderin interfacecom.google.protobuf.Message- Specified by:
toBuilderin interfacecom.google.protobuf.MessageLite
-
newBuilderForType
protected Public.DatasetCreateConstants.Builder newBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)
- Specified by:
newBuilderForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstance
public static Public.DatasetCreateConstants getDefaultInstance()
-
parser
public static com.google.protobuf.Parser<Public.DatasetCreateConstants> parser()
-
getParserForType
public com.google.protobuf.Parser<Public.DatasetCreateConstants> getParserForType()
- Specified by:
getParserForTypein interfacecom.google.protobuf.Message- Specified by:
getParserForTypein interfacecom.google.protobuf.MessageLite- Overrides:
getParserForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstanceForType
public Public.DatasetCreateConstants getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
-