Class Public.FeatureImportances

  • All Implemented Interfaces:
    Public.FeatureImportancesOrBuilder, com.google.protobuf.Message, com.google.protobuf.MessageLite, com.google.protobuf.MessageLiteOrBuilder, com.google.protobuf.MessageOrBuilder, Serializable
    Enclosing class:
    Public

    public static final class Public.FeatureImportances
    extends com.google.protobuf.GeneratedMessageV3
    implements Public.FeatureImportancesOrBuilder
     FeatureImportances contains feature importance values for a prediction
     
    Protobuf type public.FeatureImportances
    See Also:
    Serialized Form
    • Nested Class Summary

      Nested Classes 
      Modifier and Type Class Description
      static class  Public.FeatureImportances.Builder
      FeatureImportances contains feature importance values for a prediction
      • Nested classes/interfaces inherited from class com.google.protobuf.GeneratedMessageV3

        com.google.protobuf.GeneratedMessageV3.BuilderParent, com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>,​BuilderT extends com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT,​BuilderT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessageOrBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.FieldAccessorTable, com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter
      • Nested classes/interfaces inherited from class com.google.protobuf.AbstractMessageLite

        com.google.protobuf.AbstractMessageLite.InternalOneOfEnum
    • Field Summary

      Fields 
      Modifier and Type Field Description
      static int FEATURE_IMPORTANCES_FIELD_NUMBER  
      static int MODEL_VERSION_FIELD_NUMBER  
      static int TIMESTAMP_FIELD_NUMBER  
      • Fields inherited from class com.google.protobuf.GeneratedMessageV3

        alwaysUseFieldBuilders, unknownFields
      • Fields inherited from class com.google.protobuf.AbstractMessage

        memoizedSize
      • Fields inherited from class com.google.protobuf.AbstractMessageLite

        memoizedHashCode
    • Field Detail

      • MODEL_VERSION_FIELD_NUMBER

        public static final int MODEL_VERSION_FIELD_NUMBER
        See Also:
        Constant Field Values
      • FEATURE_IMPORTANCES_FIELD_NUMBER

        public static final int FEATURE_IMPORTANCES_FIELD_NUMBER
        See Also:
        Constant Field Values
    • Method Detail

      • newInstance

        protected Object newInstance​(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)
        Overrides:
        newInstance in class com.google.protobuf.GeneratedMessageV3
      • getUnknownFields

        public final com.google.protobuf.UnknownFieldSet getUnknownFields()
        Specified by:
        getUnknownFields in interface com.google.protobuf.MessageOrBuilder
        Overrides:
        getUnknownFields in class com.google.protobuf.GeneratedMessageV3
      • getDescriptor

        public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
      • internalGetMapField

        protected com.google.protobuf.MapField internalGetMapField​(int number)
        Overrides:
        internalGetMapField in class com.google.protobuf.GeneratedMessageV3
      • internalGetFieldAccessorTable

        protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()
        Specified by:
        internalGetFieldAccessorTable in class com.google.protobuf.GeneratedMessageV3
      • hasTimestamp

        public boolean hasTimestamp()
         timestamp of the feature importance values request.  If not set this will default to the time
         of receipt
         
        .google.protobuf.Timestamp timestamp = 1;
        Specified by:
        hasTimestamp in interface Public.FeatureImportancesOrBuilder
        Returns:
        Whether the timestamp field is set.
      • getTimestamp

        public com.google.protobuf.Timestamp getTimestamp()
         timestamp of the feature importance values request.  If not set this will default to the time
         of receipt
         
        .google.protobuf.Timestamp timestamp = 1;
        Specified by:
        getTimestamp in interface Public.FeatureImportancesOrBuilder
        Returns:
        The timestamp.
      • getTimestampOrBuilder

        public com.google.protobuf.TimestampOrBuilder getTimestampOrBuilder()
         timestamp of the feature importance values request.  If not set this will default to the time
         of receipt
         
        .google.protobuf.Timestamp timestamp = 1;
        Specified by:
        getTimestampOrBuilder in interface Public.FeatureImportancesOrBuilder
      • getModelVersion

        public String getModelVersion()
         model_version is a user-defined field that ensures that the feature importances are generated using the same model version as the prediction
         for a given model_id
         
        string model_version = 2;
        Specified by:
        getModelVersion in interface Public.FeatureImportancesOrBuilder
        Returns:
        The modelVersion.
      • getModelVersionBytes

        public com.google.protobuf.ByteString getModelVersionBytes()
         model_version is a user-defined field that ensures that the feature importances are generated using the same model version as the prediction
         for a given model_id
         
        string model_version = 2;
        Specified by:
        getModelVersionBytes in interface Public.FeatureImportancesOrBuilder
        Returns:
        The bytes for modelVersion.
      • getFeatureImportancesCount

        public int getFeatureImportancesCount()
        Description copied from interface: Public.FeatureImportancesOrBuilder
         importances is a map of human readable model input field containing values that will be used to group together a subset of predictions
         and feature importance values for a given model_id and model_version
         
        map<string, double> feature_importances = 3;
        Specified by:
        getFeatureImportancesCount in interface Public.FeatureImportancesOrBuilder
      • containsFeatureImportances

        public boolean containsFeatureImportances​(String key)
         importances is a map of human readable model input field containing values that will be used to group together a subset of predictions
         and feature importance values for a given model_id and model_version
         
        map<string, double> feature_importances = 3;
        Specified by:
        containsFeatureImportances in interface Public.FeatureImportancesOrBuilder
      • getFeatureImportancesMap

        public Map<String,​Double> getFeatureImportancesMap()
         importances is a map of human readable model input field containing values that will be used to group together a subset of predictions
         and feature importance values for a given model_id and model_version
         
        map<string, double> feature_importances = 3;
        Specified by:
        getFeatureImportancesMap in interface Public.FeatureImportancesOrBuilder
      • getFeatureImportancesOrDefault

        public double getFeatureImportancesOrDefault​(String key,
                                                     double defaultValue)
         importances is a map of human readable model input field containing values that will be used to group together a subset of predictions
         and feature importance values for a given model_id and model_version
         
        map<string, double> feature_importances = 3;
        Specified by:
        getFeatureImportancesOrDefault in interface Public.FeatureImportancesOrBuilder
      • getFeatureImportancesOrThrow

        public double getFeatureImportancesOrThrow​(String key)
         importances is a map of human readable model input field containing values that will be used to group together a subset of predictions
         and feature importance values for a given model_id and model_version
         
        map<string, double> feature_importances = 3;
        Specified by:
        getFeatureImportancesOrThrow in interface Public.FeatureImportancesOrBuilder
      • isInitialized

        public final boolean isInitialized()
        Specified by:
        isInitialized in interface com.google.protobuf.MessageLiteOrBuilder
        Overrides:
        isInitialized in class com.google.protobuf.GeneratedMessageV3
      • writeTo

        public void writeTo​(com.google.protobuf.CodedOutputStream output)
                     throws IOException
        Specified by:
        writeTo in interface com.google.protobuf.MessageLite
        Overrides:
        writeTo in class com.google.protobuf.GeneratedMessageV3
        Throws:
        IOException
      • getSerializedSize

        public int getSerializedSize()
        Specified by:
        getSerializedSize in interface com.google.protobuf.MessageLite
        Overrides:
        getSerializedSize in class com.google.protobuf.GeneratedMessageV3
      • equals

        public boolean equals​(Object obj)
        Specified by:
        equals in interface com.google.protobuf.Message
        Overrides:
        equals in class com.google.protobuf.AbstractMessage
      • hashCode

        public int hashCode()
        Specified by:
        hashCode in interface com.google.protobuf.Message
        Overrides:
        hashCode in class com.google.protobuf.AbstractMessage
      • parseFrom

        public static Public.FeatureImportances parseFrom​(ByteBuffer data)
                                                   throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Public.FeatureImportances parseFrom​(ByteBuffer data,
                                                          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                                   throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Public.FeatureImportances parseFrom​(com.google.protobuf.ByteString data)
                                                   throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Public.FeatureImportances parseFrom​(com.google.protobuf.ByteString data,
                                                          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                                   throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Public.FeatureImportances parseFrom​(byte[] data)
                                                   throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • parseFrom

        public static Public.FeatureImportances parseFrom​(byte[] data,
                                                          com.google.protobuf.ExtensionRegistryLite extensionRegistry)
                                                   throws com.google.protobuf.InvalidProtocolBufferException
        Throws:
        com.google.protobuf.InvalidProtocolBufferException
      • newBuilderForType

        public Public.FeatureImportances.Builder newBuilderForType()
        Specified by:
        newBuilderForType in interface com.google.protobuf.Message
        Specified by:
        newBuilderForType in interface com.google.protobuf.MessageLite
      • toBuilder

        public Public.FeatureImportances.Builder toBuilder()
        Specified by:
        toBuilder in interface com.google.protobuf.Message
        Specified by:
        toBuilder in interface com.google.protobuf.MessageLite
      • newBuilderForType

        protected Public.FeatureImportances.Builder newBuilderForType​(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)
        Specified by:
        newBuilderForType in class com.google.protobuf.GeneratedMessageV3
      • getParserForType

        public com.google.protobuf.Parser<Public.FeatureImportances> getParserForType()
        Specified by:
        getParserForType in interface com.google.protobuf.Message
        Specified by:
        getParserForType in interface com.google.protobuf.MessageLite
        Overrides:
        getParserForType in class com.google.protobuf.GeneratedMessageV3
      • getDefaultInstanceForType

        public Public.FeatureImportances getDefaultInstanceForType()
        Specified by:
        getDefaultInstanceForType in interface com.google.protobuf.MessageLiteOrBuilder
        Specified by:
        getDefaultInstanceForType in interface com.google.protobuf.MessageOrBuilder