Package com.arize.protocol
Enum Public.Label.DataCase
- java.lang.Object
-
- java.lang.Enum<Public.Label.DataCase>
-
- com.arize.protocol.Public.Label.DataCase
-
- All Implemented Interfaces:
com.google.protobuf.Internal.EnumLite,Serializable,Comparable<Public.Label.DataCase>
- Enclosing class:
- Public.Label
public static enum Public.Label.DataCase extends Enum<Public.Label.DataCase> implements com.google.protobuf.Internal.EnumLite
-
-
Enum Constant Summary
Enum Constants Enum Constant Description BINARYCATEGORICALDATA_NOT_SETNUMERICSCORE_CATEGORICAL
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Deprecated Methods Modifier and Type Method Description static Public.Label.DataCaseforNumber(int value)intgetNumber()static Public.Label.DataCasevalueOf(int value)Deprecated.static Public.Label.DataCasevalueOf(String name)Returns the enum constant of this type with the specified name.static Public.Label.DataCase[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
BINARY
public static final Public.Label.DataCase BINARY
-
CATEGORICAL
public static final Public.Label.DataCase CATEGORICAL
-
NUMERIC
public static final Public.Label.DataCase NUMERIC
-
SCORE_CATEGORICAL
public static final Public.Label.DataCase SCORE_CATEGORICAL
-
DATA_NOT_SET
public static final Public.Label.DataCase DATA_NOT_SET
-
-
Method Detail
-
values
public static Public.Label.DataCase[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (Public.Label.DataCase c : Public.Label.DataCase.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static Public.Label.DataCase valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
valueOf
@Deprecated public static Public.Label.DataCase valueOf(int value)
Deprecated.Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
value- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
forNumber
public static Public.Label.DataCase forNumber(int value)
-
getNumber
public int getNumber()
- Specified by:
getNumberin interfacecom.google.protobuf.Internal.EnumLite
-
-