Package com.arize.protocol
Enum Public.MultiClassPrediction.TypeCase
- java.lang.Object
-
- java.lang.Enum<Public.MultiClassPrediction.TypeCase>
-
- com.arize.protocol.Public.MultiClassPrediction.TypeCase
-
- All Implemented Interfaces:
com.google.protobuf.Internal.EnumLite,Serializable,Comparable<Public.MultiClassPrediction.TypeCase>
- Enclosing class:
- Public.MultiClassPrediction
public static enum Public.MultiClassPrediction.TypeCase extends Enum<Public.MultiClassPrediction.TypeCase> implements com.google.protobuf.Internal.EnumLite
-
-
Enum Constant Summary
Enum Constants Enum Constant Description MULTI_LABELSINGLE_LABELTYPE_NOT_SET
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Deprecated Methods Modifier and Type Method Description static Public.MultiClassPrediction.TypeCaseforNumber(int value)intgetNumber()static Public.MultiClassPrediction.TypeCasevalueOf(int value)Deprecated.static Public.MultiClassPrediction.TypeCasevalueOf(String name)Returns the enum constant of this type with the specified name.static Public.MultiClassPrediction.TypeCase[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
MULTI_LABEL
public static final Public.MultiClassPrediction.TypeCase MULTI_LABEL
-
SINGLE_LABEL
public static final Public.MultiClassPrediction.TypeCase SINGLE_LABEL
-
TYPE_NOT_SET
public static final Public.MultiClassPrediction.TypeCase TYPE_NOT_SET
-
-
Method Detail
-
values
public static Public.MultiClassPrediction.TypeCase[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (Public.MultiClassPrediction.TypeCase c : Public.MultiClassPrediction.TypeCase.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static Public.MultiClassPrediction.TypeCase valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
valueOf
@Deprecated public static Public.MultiClassPrediction.TypeCase valueOf(int value)
Deprecated.Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
value- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
forNumber
public static Public.MultiClassPrediction.TypeCase forNumber(int value)
-
getNumber
public int getNumber()
- Specified by:
getNumberin interfacecom.google.protobuf.Internal.EnumLite
-
-