Package com.arize.protocol
Class Public.NumericDictionary
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite
-
- com.google.protobuf.AbstractMessage
-
- com.google.protobuf.GeneratedMessageV3
-
- com.arize.protocol.Public.NumericDictionary
-
- All Implemented Interfaces:
Public.NumericDictionaryOrBuilder,com.google.protobuf.Message,com.google.protobuf.MessageLite,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,Serializable
- Enclosing class:
- Public
public static final class Public.NumericDictionary extends com.google.protobuf.GeneratedMessageV3 implements Public.NumericDictionaryOrBuilder
Protobuf typepublic.NumericDictionary- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classPublic.NumericDictionary.BuilderProtobuf typepublic.NumericDictionary-
Nested classes/interfaces inherited from class com.google.protobuf.GeneratedMessageV3
com.google.protobuf.GeneratedMessageV3.BuilderParent, com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>,BuilderT extends com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT,BuilderT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessageOrBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.FieldAccessorTable, com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter
-
-
Field Summary
Fields Modifier and Type Field Description static intVALUES_FIELD_NUMBER
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Deprecated Methods Modifier and Type Method Description booleancontainsValues(String key)map<string, .google.protobuf.DoubleValue> values = 1;booleanequals(Object obj)static Public.NumericDictionarygetDefaultInstance()Public.NumericDictionarygetDefaultInstanceForType()static com.google.protobuf.Descriptors.DescriptorgetDescriptor()com.google.protobuf.Parser<Public.NumericDictionary>getParserForType()intgetSerializedSize()com.google.protobuf.UnknownFieldSetgetUnknownFields()Map<String,com.google.protobuf.DoubleValue>getValues()Deprecated.intgetValuesCount()map<string, .google.protobuf.DoubleValue> values = 1;Map<String,com.google.protobuf.DoubleValue>getValuesMap()map<string, .google.protobuf.DoubleValue> values = 1;com.google.protobuf.DoubleValuegetValuesOrDefault(String key, com.google.protobuf.DoubleValue defaultValue)map<string, .google.protobuf.DoubleValue> values = 1;com.google.protobuf.DoubleValuegetValuesOrThrow(String key)map<string, .google.protobuf.DoubleValue> values = 1;inthashCode()protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTableinternalGetFieldAccessorTable()protected com.google.protobuf.MapFieldinternalGetMapField(int number)booleanisInitialized()static Public.NumericDictionary.BuildernewBuilder()static Public.NumericDictionary.BuildernewBuilder(Public.NumericDictionary prototype)Public.NumericDictionary.BuildernewBuilderForType()protected Public.NumericDictionary.BuildernewBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)protected ObjectnewInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)static Public.NumericDictionaryparseDelimitedFrom(InputStream input)static Public.NumericDictionaryparseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.NumericDictionaryparseFrom(byte[] data)static Public.NumericDictionaryparseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.NumericDictionaryparseFrom(com.google.protobuf.ByteString data)static Public.NumericDictionaryparseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.NumericDictionaryparseFrom(com.google.protobuf.CodedInputStream input)static Public.NumericDictionaryparseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.NumericDictionaryparseFrom(InputStream input)static Public.NumericDictionaryparseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.NumericDictionaryparseFrom(ByteBuffer data)static Public.NumericDictionaryparseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static com.google.protobuf.Parser<Public.NumericDictionary>parser()Public.NumericDictionary.BuildertoBuilder()voidwriteTo(com.google.protobuf.CodedOutputStream output)-
Methods inherited from class com.google.protobuf.GeneratedMessageV3
canUseUnsafe, computeStringSize, computeStringSizeNoTag, emptyBooleanList, emptyDoubleList, emptyFloatList, emptyIntList, emptyList, emptyLongList, getAllFields, getDescriptorForType, getField, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, hasField, hasOneof, internalGetMapFieldReflection, isStringEmpty, makeExtensionsImmutable, makeMutableCopy, makeMutableCopy, mergeFromAndMakeImmutableInternal, mutableCopy, mutableCopy, mutableCopy, mutableCopy, mutableCopy, newBooleanList, newBuilderForType, newDoubleList, newFloatList, newIntList, newLongList, parseDelimitedWithIOException, parseDelimitedWithIOException, parseUnknownField, parseUnknownFieldProto3, parseWithIOException, parseWithIOException, parseWithIOException, parseWithIOException, serializeBooleanMapTo, serializeIntegerMapTo, serializeLongMapTo, serializeStringMapTo, writeReplace, writeString, writeStringNoTag
-
Methods inherited from class com.google.protobuf.AbstractMessage
findInitializationErrors, getInitializationErrorString, hashBoolean, hashEnum, hashEnumList, hashFields, hashLong, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite
addAll, addAll, checkByteStringIsUtf8, toByteArray, toByteString, writeDelimitedTo, writeTo
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
-
-
-
Field Detail
-
VALUES_FIELD_NUMBER
public static final int VALUES_FIELD_NUMBER
- See Also:
- Constant Field Values
-
-
Method Detail
-
newInstance
protected Object newInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)
- Overrides:
newInstancein classcom.google.protobuf.GeneratedMessageV3
-
getUnknownFields
public final com.google.protobuf.UnknownFieldSet getUnknownFields()
- Specified by:
getUnknownFieldsin interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getUnknownFieldsin classcom.google.protobuf.GeneratedMessageV3
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetMapField
protected com.google.protobuf.MapField internalGetMapField(int number)
- Overrides:
internalGetMapFieldin classcom.google.protobuf.GeneratedMessageV3
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessageV3
-
getValuesCount
public int getValuesCount()
Description copied from interface:Public.NumericDictionaryOrBuildermap<string, .google.protobuf.DoubleValue> values = 1;- Specified by:
getValuesCountin interfacePublic.NumericDictionaryOrBuilder
-
containsValues
public boolean containsValues(String key)
map<string, .google.protobuf.DoubleValue> values = 1;- Specified by:
containsValuesin interfacePublic.NumericDictionaryOrBuilder
-
getValues
@Deprecated public Map<String,com.google.protobuf.DoubleValue> getValues()
Deprecated.UsegetValuesMap()instead.- Specified by:
getValuesin interfacePublic.NumericDictionaryOrBuilder
-
getValuesMap
public Map<String,com.google.protobuf.DoubleValue> getValuesMap()
map<string, .google.protobuf.DoubleValue> values = 1;- Specified by:
getValuesMapin interfacePublic.NumericDictionaryOrBuilder
-
getValuesOrDefault
public com.google.protobuf.DoubleValue getValuesOrDefault(String key, com.google.protobuf.DoubleValue defaultValue)
map<string, .google.protobuf.DoubleValue> values = 1;- Specified by:
getValuesOrDefaultin interfacePublic.NumericDictionaryOrBuilder
-
getValuesOrThrow
public com.google.protobuf.DoubleValue getValuesOrThrow(String key)
map<string, .google.protobuf.DoubleValue> values = 1;- Specified by:
getValuesOrThrowin interfacePublic.NumericDictionaryOrBuilder
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessageV3
-
writeTo
public void writeTo(com.google.protobuf.CodedOutputStream output) throws IOException- Specified by:
writeToin interfacecom.google.protobuf.MessageLite- Overrides:
writeToin classcom.google.protobuf.GeneratedMessageV3- Throws:
IOException
-
getSerializedSize
public int getSerializedSize()
- Specified by:
getSerializedSizein interfacecom.google.protobuf.MessageLite- Overrides:
getSerializedSizein classcom.google.protobuf.GeneratedMessageV3
-
equals
public boolean equals(Object obj)
- Specified by:
equalsin interfacecom.google.protobuf.Message- Overrides:
equalsin classcom.google.protobuf.AbstractMessage
-
hashCode
public int hashCode()
- Specified by:
hashCodein interfacecom.google.protobuf.Message- Overrides:
hashCodein classcom.google.protobuf.AbstractMessage
-
parseFrom
public static Public.NumericDictionary parseFrom(ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.NumericDictionary parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.NumericDictionary parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.NumericDictionary parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.NumericDictionary parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.NumericDictionary parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.NumericDictionary parseFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.NumericDictionary parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.NumericDictionary parseDelimitedFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.NumericDictionary parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.NumericDictionary parseFrom(com.google.protobuf.CodedInputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.NumericDictionary parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
newBuilderForType
public Public.NumericDictionary.Builder newBuilderForType()
- Specified by:
newBuilderForTypein interfacecom.google.protobuf.Message- Specified by:
newBuilderForTypein interfacecom.google.protobuf.MessageLite
-
newBuilder
public static Public.NumericDictionary.Builder newBuilder()
-
newBuilder
public static Public.NumericDictionary.Builder newBuilder(Public.NumericDictionary prototype)
-
toBuilder
public Public.NumericDictionary.Builder toBuilder()
- Specified by:
toBuilderin interfacecom.google.protobuf.Message- Specified by:
toBuilderin interfacecom.google.protobuf.MessageLite
-
newBuilderForType
protected Public.NumericDictionary.Builder newBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)
- Specified by:
newBuilderForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstance
public static Public.NumericDictionary getDefaultInstance()
-
parser
public static com.google.protobuf.Parser<Public.NumericDictionary> parser()
-
getParserForType
public com.google.protobuf.Parser<Public.NumericDictionary> getParserForType()
- Specified by:
getParserForTypein interfacecom.google.protobuf.Message- Specified by:
getParserForTypein interfacecom.google.protobuf.MessageLite- Overrides:
getParserForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstanceForType
public Public.NumericDictionary getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
-