Package com.arize.protocol
Class Public.ObjectDetection
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite
-
- com.google.protobuf.AbstractMessage
-
- com.google.protobuf.GeneratedMessageV3
-
- com.arize.protocol.Public.ObjectDetection
-
- All Implemented Interfaces:
Public.ObjectDetectionOrBuilder,com.google.protobuf.Message,com.google.protobuf.MessageLite,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,Serializable
- Enclosing class:
- Public
public static final class Public.ObjectDetection extends com.google.protobuf.GeneratedMessageV3 implements Public.ObjectDetectionOrBuilder
ObjectDetection represents a single image in an object detection model that may contain many bounding boxes
Protobuf typepublic.ObjectDetection- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classPublic.ObjectDetection.BoundingBoxProtobuf typepublic.ObjectDetection.BoundingBoxstatic interfacePublic.ObjectDetection.BoundingBoxOrBuilderstatic classPublic.ObjectDetection.BuilderObjectDetection represents a single image in an object detection model that may contain many bounding boxes-
Nested classes/interfaces inherited from class com.google.protobuf.GeneratedMessageV3
com.google.protobuf.GeneratedMessageV3.BuilderParent, com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>,BuilderT extends com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT,BuilderT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessageOrBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.FieldAccessorTable, com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter
-
-
Field Summary
Fields Modifier and Type Field Description static intBOUNDING_BOXES_FIELD_NUMBER
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(Object obj)Public.ObjectDetection.BoundingBoxgetBoundingBoxes(int index)repeated .public.ObjectDetection.BoundingBox bounding_boxes = 1;intgetBoundingBoxesCount()repeated .public.ObjectDetection.BoundingBox bounding_boxes = 1;List<Public.ObjectDetection.BoundingBox>getBoundingBoxesList()repeated .public.ObjectDetection.BoundingBox bounding_boxes = 1;Public.ObjectDetection.BoundingBoxOrBuildergetBoundingBoxesOrBuilder(int index)repeated .public.ObjectDetection.BoundingBox bounding_boxes = 1;List<? extends Public.ObjectDetection.BoundingBoxOrBuilder>getBoundingBoxesOrBuilderList()repeated .public.ObjectDetection.BoundingBox bounding_boxes = 1;static Public.ObjectDetectiongetDefaultInstance()Public.ObjectDetectiongetDefaultInstanceForType()static com.google.protobuf.Descriptors.DescriptorgetDescriptor()com.google.protobuf.Parser<Public.ObjectDetection>getParserForType()intgetSerializedSize()com.google.protobuf.UnknownFieldSetgetUnknownFields()inthashCode()protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTableinternalGetFieldAccessorTable()booleanisInitialized()static Public.ObjectDetection.BuildernewBuilder()static Public.ObjectDetection.BuildernewBuilder(Public.ObjectDetection prototype)Public.ObjectDetection.BuildernewBuilderForType()protected Public.ObjectDetection.BuildernewBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)protected ObjectnewInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)static Public.ObjectDetectionparseDelimitedFrom(InputStream input)static Public.ObjectDetectionparseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.ObjectDetectionparseFrom(byte[] data)static Public.ObjectDetectionparseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.ObjectDetectionparseFrom(com.google.protobuf.ByteString data)static Public.ObjectDetectionparseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.ObjectDetectionparseFrom(com.google.protobuf.CodedInputStream input)static Public.ObjectDetectionparseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.ObjectDetectionparseFrom(InputStream input)static Public.ObjectDetectionparseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.ObjectDetectionparseFrom(ByteBuffer data)static Public.ObjectDetectionparseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static com.google.protobuf.Parser<Public.ObjectDetection>parser()Public.ObjectDetection.BuildertoBuilder()voidwriteTo(com.google.protobuf.CodedOutputStream output)-
Methods inherited from class com.google.protobuf.GeneratedMessageV3
canUseUnsafe, computeStringSize, computeStringSizeNoTag, emptyBooleanList, emptyDoubleList, emptyFloatList, emptyIntList, emptyList, emptyLongList, getAllFields, getDescriptorForType, getField, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, isStringEmpty, makeExtensionsImmutable, makeMutableCopy, makeMutableCopy, mergeFromAndMakeImmutableInternal, mutableCopy, mutableCopy, mutableCopy, mutableCopy, mutableCopy, newBooleanList, newBuilderForType, newDoubleList, newFloatList, newIntList, newLongList, parseDelimitedWithIOException, parseDelimitedWithIOException, parseUnknownField, parseUnknownFieldProto3, parseWithIOException, parseWithIOException, parseWithIOException, parseWithIOException, serializeBooleanMapTo, serializeIntegerMapTo, serializeLongMapTo, serializeStringMapTo, writeReplace, writeString, writeStringNoTag
-
Methods inherited from class com.google.protobuf.AbstractMessage
findInitializationErrors, getInitializationErrorString, hashBoolean, hashEnum, hashEnumList, hashFields, hashLong, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite
addAll, addAll, checkByteStringIsUtf8, toByteArray, toByteString, writeDelimitedTo, writeTo
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
-
-
-
Field Detail
-
BOUNDING_BOXES_FIELD_NUMBER
public static final int BOUNDING_BOXES_FIELD_NUMBER
- See Also:
- Constant Field Values
-
-
Method Detail
-
newInstance
protected Object newInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)
- Overrides:
newInstancein classcom.google.protobuf.GeneratedMessageV3
-
getUnknownFields
public final com.google.protobuf.UnknownFieldSet getUnknownFields()
- Specified by:
getUnknownFieldsin interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getUnknownFieldsin classcom.google.protobuf.GeneratedMessageV3
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessageV3
-
getBoundingBoxesList
public List<Public.ObjectDetection.BoundingBox> getBoundingBoxesList()
repeated .public.ObjectDetection.BoundingBox bounding_boxes = 1;- Specified by:
getBoundingBoxesListin interfacePublic.ObjectDetectionOrBuilder
-
getBoundingBoxesOrBuilderList
public List<? extends Public.ObjectDetection.BoundingBoxOrBuilder> getBoundingBoxesOrBuilderList()
repeated .public.ObjectDetection.BoundingBox bounding_boxes = 1;- Specified by:
getBoundingBoxesOrBuilderListin interfacePublic.ObjectDetectionOrBuilder
-
getBoundingBoxesCount
public int getBoundingBoxesCount()
repeated .public.ObjectDetection.BoundingBox bounding_boxes = 1;- Specified by:
getBoundingBoxesCountin interfacePublic.ObjectDetectionOrBuilder
-
getBoundingBoxes
public Public.ObjectDetection.BoundingBox getBoundingBoxes(int index)
repeated .public.ObjectDetection.BoundingBox bounding_boxes = 1;- Specified by:
getBoundingBoxesin interfacePublic.ObjectDetectionOrBuilder
-
getBoundingBoxesOrBuilder
public Public.ObjectDetection.BoundingBoxOrBuilder getBoundingBoxesOrBuilder(int index)
repeated .public.ObjectDetection.BoundingBox bounding_boxes = 1;- Specified by:
getBoundingBoxesOrBuilderin interfacePublic.ObjectDetectionOrBuilder
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessageV3
-
writeTo
public void writeTo(com.google.protobuf.CodedOutputStream output) throws IOException- Specified by:
writeToin interfacecom.google.protobuf.MessageLite- Overrides:
writeToin classcom.google.protobuf.GeneratedMessageV3- Throws:
IOException
-
getSerializedSize
public int getSerializedSize()
- Specified by:
getSerializedSizein interfacecom.google.protobuf.MessageLite- Overrides:
getSerializedSizein classcom.google.protobuf.GeneratedMessageV3
-
equals
public boolean equals(Object obj)
- Specified by:
equalsin interfacecom.google.protobuf.Message- Overrides:
equalsin classcom.google.protobuf.AbstractMessage
-
hashCode
public int hashCode()
- Specified by:
hashCodein interfacecom.google.protobuf.Message- Overrides:
hashCodein classcom.google.protobuf.AbstractMessage
-
parseFrom
public static Public.ObjectDetection parseFrom(ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.ObjectDetection parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.ObjectDetection parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.ObjectDetection parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.ObjectDetection parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.ObjectDetection parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.ObjectDetection parseFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.ObjectDetection parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.ObjectDetection parseDelimitedFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.ObjectDetection parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.ObjectDetection parseFrom(com.google.protobuf.CodedInputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.ObjectDetection parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
newBuilderForType
public Public.ObjectDetection.Builder newBuilderForType()
- Specified by:
newBuilderForTypein interfacecom.google.protobuf.Message- Specified by:
newBuilderForTypein interfacecom.google.protobuf.MessageLite
-
newBuilder
public static Public.ObjectDetection.Builder newBuilder()
-
newBuilder
public static Public.ObjectDetection.Builder newBuilder(Public.ObjectDetection prototype)
-
toBuilder
public Public.ObjectDetection.Builder toBuilder()
- Specified by:
toBuilderin interfacecom.google.protobuf.Message- Specified by:
toBuilderin interfacecom.google.protobuf.MessageLite
-
newBuilderForType
protected Public.ObjectDetection.Builder newBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)
- Specified by:
newBuilderForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstance
public static Public.ObjectDetection getDefaultInstance()
-
parser
public static com.google.protobuf.Parser<Public.ObjectDetection> parser()
-
getParserForType
public com.google.protobuf.Parser<Public.ObjectDetection> getParserForType()
- Specified by:
getParserForTypein interfacecom.google.protobuf.Message- Specified by:
getParserForTypein interfacecom.google.protobuf.MessageLite- Overrides:
getParserForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstanceForType
public Public.ObjectDetection getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
-