Package com.arize.protocol
Class Public.ObjectDetection.BoundingBox
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite
-
- com.google.protobuf.AbstractMessage
-
- com.google.protobuf.GeneratedMessageV3
-
- com.arize.protocol.Public.ObjectDetection.BoundingBox
-
- All Implemented Interfaces:
Public.ObjectDetection.BoundingBoxOrBuilder,com.google.protobuf.Message,com.google.protobuf.MessageLite,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,Serializable
- Enclosing class:
- Public.ObjectDetection
public static final class Public.ObjectDetection.BoundingBox extends com.google.protobuf.GeneratedMessageV3 implements Public.ObjectDetection.BoundingBoxOrBuilder
Protobuf typepublic.ObjectDetection.BoundingBox- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classPublic.ObjectDetection.BoundingBox.BuilderProtobuf typepublic.ObjectDetection.BoundingBox-
Nested classes/interfaces inherited from class com.google.protobuf.GeneratedMessageV3
com.google.protobuf.GeneratedMessageV3.BuilderParent, com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>,BuilderT extends com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT,BuilderT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessageOrBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.FieldAccessorTable, com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter
-
-
Field Summary
Fields Modifier and Type Field Description static intCATEGORY_FIELD_NUMBERstatic intCOORDINATES_FIELD_NUMBERstatic intSCORE_FIELD_NUMBER
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(Object obj)StringgetCategory()category/class of bounding boxcom.google.protobuf.ByteStringgetCategoryBytes()category/class of bounding boxdoublegetCoordinates(int index)format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixelsintgetCoordinatesCount()format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixelsList<Double>getCoordinatesList()format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixelsstatic Public.ObjectDetection.BoundingBoxgetDefaultInstance()Public.ObjectDetection.BoundingBoxgetDefaultInstanceForType()static com.google.protobuf.Descriptors.DescriptorgetDescriptor()com.google.protobuf.Parser<Public.ObjectDetection.BoundingBox>getParserForType()com.google.protobuf.DoubleValuegetScore()score/confidence of bounding boxcom.google.protobuf.DoubleValueOrBuildergetScoreOrBuilder()score/confidence of bounding boxintgetSerializedSize()com.google.protobuf.UnknownFieldSetgetUnknownFields()inthashCode()booleanhasScore()score/confidence of bounding boxprotected com.google.protobuf.GeneratedMessageV3.FieldAccessorTableinternalGetFieldAccessorTable()booleanisInitialized()static Public.ObjectDetection.BoundingBox.BuildernewBuilder()static Public.ObjectDetection.BoundingBox.BuildernewBuilder(Public.ObjectDetection.BoundingBox prototype)Public.ObjectDetection.BoundingBox.BuildernewBuilderForType()protected Public.ObjectDetection.BoundingBox.BuildernewBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)protected ObjectnewInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)static Public.ObjectDetection.BoundingBoxparseDelimitedFrom(InputStream input)static Public.ObjectDetection.BoundingBoxparseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.ObjectDetection.BoundingBoxparseFrom(byte[] data)static Public.ObjectDetection.BoundingBoxparseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.ObjectDetection.BoundingBoxparseFrom(com.google.protobuf.ByteString data)static Public.ObjectDetection.BoundingBoxparseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.ObjectDetection.BoundingBoxparseFrom(com.google.protobuf.CodedInputStream input)static Public.ObjectDetection.BoundingBoxparseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.ObjectDetection.BoundingBoxparseFrom(InputStream input)static Public.ObjectDetection.BoundingBoxparseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.ObjectDetection.BoundingBoxparseFrom(ByteBuffer data)static Public.ObjectDetection.BoundingBoxparseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static com.google.protobuf.Parser<Public.ObjectDetection.BoundingBox>parser()Public.ObjectDetection.BoundingBox.BuildertoBuilder()voidwriteTo(com.google.protobuf.CodedOutputStream output)-
Methods inherited from class com.google.protobuf.GeneratedMessageV3
canUseUnsafe, computeStringSize, computeStringSizeNoTag, emptyBooleanList, emptyDoubleList, emptyFloatList, emptyIntList, emptyList, emptyLongList, getAllFields, getDescriptorForType, getField, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, isStringEmpty, makeExtensionsImmutable, makeMutableCopy, makeMutableCopy, mergeFromAndMakeImmutableInternal, mutableCopy, mutableCopy, mutableCopy, mutableCopy, mutableCopy, newBooleanList, newBuilderForType, newDoubleList, newFloatList, newIntList, newLongList, parseDelimitedWithIOException, parseDelimitedWithIOException, parseUnknownField, parseUnknownFieldProto3, parseWithIOException, parseWithIOException, parseWithIOException, parseWithIOException, serializeBooleanMapTo, serializeIntegerMapTo, serializeLongMapTo, serializeStringMapTo, writeReplace, writeString, writeStringNoTag
-
Methods inherited from class com.google.protobuf.AbstractMessage
findInitializationErrors, getInitializationErrorString, hashBoolean, hashEnum, hashEnumList, hashFields, hashLong, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite
addAll, addAll, checkByteStringIsUtf8, toByteArray, toByteString, writeDelimitedTo, writeTo
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
-
-
-
Field Detail
-
COORDINATES_FIELD_NUMBER
public static final int COORDINATES_FIELD_NUMBER
- See Also:
- Constant Field Values
-
CATEGORY_FIELD_NUMBER
public static final int CATEGORY_FIELD_NUMBER
- See Also:
- Constant Field Values
-
SCORE_FIELD_NUMBER
public static final int SCORE_FIELD_NUMBER
- See Also:
- Constant Field Values
-
-
Method Detail
-
newInstance
protected Object newInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)
- Overrides:
newInstancein classcom.google.protobuf.GeneratedMessageV3
-
getUnknownFields
public final com.google.protobuf.UnknownFieldSet getUnknownFields()
- Specified by:
getUnknownFieldsin interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getUnknownFieldsin classcom.google.protobuf.GeneratedMessageV3
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessageV3
-
getCoordinatesList
public List<Double> getCoordinatesList()
format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixels
repeated double coordinates = 1;- Specified by:
getCoordinatesListin interfacePublic.ObjectDetection.BoundingBoxOrBuilder- Returns:
- A list containing the coordinates.
-
getCoordinatesCount
public int getCoordinatesCount()
format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixels
repeated double coordinates = 1;- Specified by:
getCoordinatesCountin interfacePublic.ObjectDetection.BoundingBoxOrBuilder- Returns:
- The count of coordinates.
-
getCoordinates
public double getCoordinates(int index)
format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixels
repeated double coordinates = 1;- Specified by:
getCoordinatesin interfacePublic.ObjectDetection.BoundingBoxOrBuilder- Parameters:
index- The index of the element to return.- Returns:
- The coordinates at the given index.
-
getCategory
public String getCategory()
category/class of bounding box
string category = 2;- Specified by:
getCategoryin interfacePublic.ObjectDetection.BoundingBoxOrBuilder- Returns:
- The category.
-
getCategoryBytes
public com.google.protobuf.ByteString getCategoryBytes()
category/class of bounding box
string category = 2;- Specified by:
getCategoryBytesin interfacePublic.ObjectDetection.BoundingBoxOrBuilder- Returns:
- The bytes for category.
-
hasScore
public boolean hasScore()
score/confidence of bounding box
.google.protobuf.DoubleValue score = 3;- Specified by:
hasScorein interfacePublic.ObjectDetection.BoundingBoxOrBuilder- Returns:
- Whether the score field is set.
-
getScore
public com.google.protobuf.DoubleValue getScore()
score/confidence of bounding box
.google.protobuf.DoubleValue score = 3;- Specified by:
getScorein interfacePublic.ObjectDetection.BoundingBoxOrBuilder- Returns:
- The score.
-
getScoreOrBuilder
public com.google.protobuf.DoubleValueOrBuilder getScoreOrBuilder()
score/confidence of bounding box
.google.protobuf.DoubleValue score = 3;- Specified by:
getScoreOrBuilderin interfacePublic.ObjectDetection.BoundingBoxOrBuilder
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessageV3
-
writeTo
public void writeTo(com.google.protobuf.CodedOutputStream output) throws IOException- Specified by:
writeToin interfacecom.google.protobuf.MessageLite- Overrides:
writeToin classcom.google.protobuf.GeneratedMessageV3- Throws:
IOException
-
getSerializedSize
public int getSerializedSize()
- Specified by:
getSerializedSizein interfacecom.google.protobuf.MessageLite- Overrides:
getSerializedSizein classcom.google.protobuf.GeneratedMessageV3
-
equals
public boolean equals(Object obj)
- Specified by:
equalsin interfacecom.google.protobuf.Message- Overrides:
equalsin classcom.google.protobuf.AbstractMessage
-
hashCode
public int hashCode()
- Specified by:
hashCodein interfacecom.google.protobuf.Message- Overrides:
hashCodein classcom.google.protobuf.AbstractMessage
-
parseFrom
public static Public.ObjectDetection.BoundingBox parseFrom(ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.ObjectDetection.BoundingBox parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.ObjectDetection.BoundingBox parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.ObjectDetection.BoundingBox parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.ObjectDetection.BoundingBox parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.ObjectDetection.BoundingBox parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.ObjectDetection.BoundingBox parseFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.ObjectDetection.BoundingBox parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.ObjectDetection.BoundingBox parseDelimitedFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.ObjectDetection.BoundingBox parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.ObjectDetection.BoundingBox parseFrom(com.google.protobuf.CodedInputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.ObjectDetection.BoundingBox parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
newBuilderForType
public Public.ObjectDetection.BoundingBox.Builder newBuilderForType()
- Specified by:
newBuilderForTypein interfacecom.google.protobuf.Message- Specified by:
newBuilderForTypein interfacecom.google.protobuf.MessageLite
-
newBuilder
public static Public.ObjectDetection.BoundingBox.Builder newBuilder()
-
newBuilder
public static Public.ObjectDetection.BoundingBox.Builder newBuilder(Public.ObjectDetection.BoundingBox prototype)
-
toBuilder
public Public.ObjectDetection.BoundingBox.Builder toBuilder()
- Specified by:
toBuilderin interfacecom.google.protobuf.Message- Specified by:
toBuilderin interfacecom.google.protobuf.MessageLite
-
newBuilderForType
protected Public.ObjectDetection.BoundingBox.Builder newBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)
- Specified by:
newBuilderForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstance
public static Public.ObjectDetection.BoundingBox getDefaultInstance()
-
parser
public static com.google.protobuf.Parser<Public.ObjectDetection.BoundingBox> parser()
-
getParserForType
public com.google.protobuf.Parser<Public.ObjectDetection.BoundingBox> getParserForType()
- Specified by:
getParserForTypein interfacecom.google.protobuf.Message- Specified by:
getParserForTypein interfacecom.google.protobuf.MessageLite- Overrides:
getParserForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstanceForType
public Public.ObjectDetection.BoundingBox getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
-