Class Public.PredictionInstanceSegmentationPolygon

  • All Implemented Interfaces:
    Public.PredictionInstanceSegmentationPolygonOrBuilder, com.google.protobuf.Message, com.google.protobuf.MessageLite, com.google.protobuf.MessageLiteOrBuilder, com.google.protobuf.MessageOrBuilder, Serializable
    Enclosing class:
    Public

    public static final class Public.PredictionInstanceSegmentationPolygon
    extends com.google.protobuf.GeneratedMessageV3
    implements Public.PredictionInstanceSegmentationPolygonOrBuilder
     PredictionInstanceSegmentationPolygon contains the coordinates to define the polygon shape, the category of the polygon,
     the score of the polygon, and the absolute coordinates of the bounding box that contains the polygon. Coordiantes
     and category are required while score and bbox_coordinates are optional.
     
    Protobuf type public.PredictionInstanceSegmentationPolygon
    See Also:
    Serialized Form