Package com.arize.protocol
Class Public.PredictionInstanceSegmentationPolygon.Builder
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite.Builder
-
- com.google.protobuf.AbstractMessage.Builder<BuilderT>
-
- com.google.protobuf.GeneratedMessageV3.Builder<Public.PredictionInstanceSegmentationPolygon.Builder>
-
- com.arize.protocol.Public.PredictionInstanceSegmentationPolygon.Builder
-
- All Implemented Interfaces:
Public.PredictionInstanceSegmentationPolygonOrBuilder,com.google.protobuf.Message.Builder,com.google.protobuf.MessageLite.Builder,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,Cloneable
- Enclosing class:
- Public.PredictionInstanceSegmentationPolygon
public static final class Public.PredictionInstanceSegmentationPolygon.Builder extends com.google.protobuf.GeneratedMessageV3.Builder<Public.PredictionInstanceSegmentationPolygon.Builder> implements Public.PredictionInstanceSegmentationPolygonOrBuilder
PredictionInstanceSegmentationPolygon contains the coordinates to define the polygon shape, the category of the polygon, the score of the polygon, and the absolute coordinates of the bounding box that contains the polygon. Coordiantes and category are required while score and bbox_coordinates are optional.
Protobuf typepublic.PredictionInstanceSegmentationPolygon
-
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description Public.PredictionInstanceSegmentationPolygon.BuilderaddAllBboxCoordinates(Iterable<? extends Double> values)format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixelsPublic.PredictionInstanceSegmentationPolygon.BuilderaddAllCoordinates(Iterable<? extends Double> values)format (x,y,x,y...Public.PredictionInstanceSegmentationPolygon.BuilderaddBboxCoordinates(double value)format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixelsPublic.PredictionInstanceSegmentationPolygon.BuilderaddCoordinates(double value)format (x,y,x,y...Public.PredictionInstanceSegmentationPolygon.BuilderaddRepeatedField(com.google.protobuf.Descriptors.FieldDescriptor field, Object value)Public.PredictionInstanceSegmentationPolygonbuild()Public.PredictionInstanceSegmentationPolygonbuildPartial()Public.PredictionInstanceSegmentationPolygon.Builderclear()Public.PredictionInstanceSegmentationPolygon.BuilderclearBboxCoordinates()format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixelsPublic.PredictionInstanceSegmentationPolygon.BuilderclearCategory()string category = 3;Public.PredictionInstanceSegmentationPolygon.BuilderclearCoordinates()format (x,y,x,y...Public.PredictionInstanceSegmentationPolygon.BuilderclearField(com.google.protobuf.Descriptors.FieldDescriptor field)Public.PredictionInstanceSegmentationPolygon.BuilderclearOneof(com.google.protobuf.Descriptors.OneofDescriptor oneof)Public.PredictionInstanceSegmentationPolygon.BuilderclearScore().google.protobuf.DoubleValue score = 4;Public.PredictionInstanceSegmentationPolygon.Builderclone()doublegetBboxCoordinates(int index)format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixelsintgetBboxCoordinatesCount()format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixelsList<Double>getBboxCoordinatesList()format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixelsStringgetCategory()string category = 3;com.google.protobuf.ByteStringgetCategoryBytes()string category = 3;doublegetCoordinates(int index)format (x,y,x,y...intgetCoordinatesCount()format (x,y,x,y...List<Double>getCoordinatesList()format (x,y,x,y...Public.PredictionInstanceSegmentationPolygongetDefaultInstanceForType()static com.google.protobuf.Descriptors.DescriptorgetDescriptor()com.google.protobuf.Descriptors.DescriptorgetDescriptorForType()com.google.protobuf.DoubleValuegetScore().google.protobuf.DoubleValue score = 4;com.google.protobuf.DoubleValue.BuildergetScoreBuilder().google.protobuf.DoubleValue score = 4;com.google.protobuf.DoubleValueOrBuildergetScoreOrBuilder().google.protobuf.DoubleValue score = 4;booleanhasScore().google.protobuf.DoubleValue score = 4;protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTableinternalGetFieldAccessorTable()booleanisInitialized()Public.PredictionInstanceSegmentationPolygon.BuildermergeFrom(Public.PredictionInstanceSegmentationPolygon other)Public.PredictionInstanceSegmentationPolygon.BuildermergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)Public.PredictionInstanceSegmentationPolygon.BuildermergeFrom(com.google.protobuf.Message other)Public.PredictionInstanceSegmentationPolygon.BuildermergeScore(com.google.protobuf.DoubleValue value).google.protobuf.DoubleValue score = 4;Public.PredictionInstanceSegmentationPolygon.BuildermergeUnknownFields(com.google.protobuf.UnknownFieldSet unknownFields)Public.PredictionInstanceSegmentationPolygon.BuildersetBboxCoordinates(int index, double value)format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixelsPublic.PredictionInstanceSegmentationPolygon.BuildersetCategory(String value)string category = 3;Public.PredictionInstanceSegmentationPolygon.BuildersetCategoryBytes(com.google.protobuf.ByteString value)string category = 3;Public.PredictionInstanceSegmentationPolygon.BuildersetCoordinates(int index, double value)format (x,y,x,y...Public.PredictionInstanceSegmentationPolygon.BuildersetField(com.google.protobuf.Descriptors.FieldDescriptor field, Object value)Public.PredictionInstanceSegmentationPolygon.BuildersetRepeatedField(com.google.protobuf.Descriptors.FieldDescriptor field, int index, Object value)Public.PredictionInstanceSegmentationPolygon.BuildersetScore(com.google.protobuf.DoubleValue value).google.protobuf.DoubleValue score = 4;Public.PredictionInstanceSegmentationPolygon.BuildersetScore(com.google.protobuf.DoubleValue.Builder builderForValue).google.protobuf.DoubleValue score = 4;Public.PredictionInstanceSegmentationPolygon.BuildersetUnknownFields(com.google.protobuf.UnknownFieldSet unknownFields)-
Methods inherited from class com.google.protobuf.GeneratedMessageV3.Builder
getAllFields, getField, getFieldBuilder, getOneofFieldDescriptor, getParentForChildren, getRepeatedField, getRepeatedFieldBuilder, getRepeatedFieldCount, getUnknownFields, getUnknownFieldSetBuilder, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, internalGetMutableMapField, internalGetMutableMapFieldReflection, isClean, markClean, mergeUnknownLengthDelimitedField, mergeUnknownVarintField, newBuilderForField, onBuilt, onChanged, parseUnknownField, setUnknownFieldSetBuilder, setUnknownFieldsProto3
-
Methods inherited from class com.google.protobuf.AbstractMessage.Builder
findInitializationErrors, getInitializationErrorString, internalMergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, mergeFrom, newUninitializedMessageException, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite.Builder
addAll, addAll, mergeDelimitedFrom, mergeDelimitedFrom, mergeFrom, newUninitializedMessageException
-
Methods inherited from class java.lang.Object
equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait
-
-
-
-
Method Detail
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessageV3.Builder<Public.PredictionInstanceSegmentationPolygon.Builder>
-
clear
public Public.PredictionInstanceSegmentationPolygon.Builder clear()
- Specified by:
clearin interfacecom.google.protobuf.Message.Builder- Specified by:
clearin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
clearin classcom.google.protobuf.GeneratedMessageV3.Builder<Public.PredictionInstanceSegmentationPolygon.Builder>
-
getDescriptorForType
public com.google.protobuf.Descriptors.Descriptor getDescriptorForType()
- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.Message.Builder- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getDescriptorForTypein classcom.google.protobuf.GeneratedMessageV3.Builder<Public.PredictionInstanceSegmentationPolygon.Builder>
-
getDefaultInstanceForType
public Public.PredictionInstanceSegmentationPolygon getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
build
public Public.PredictionInstanceSegmentationPolygon build()
- Specified by:
buildin interfacecom.google.protobuf.Message.Builder- Specified by:
buildin interfacecom.google.protobuf.MessageLite.Builder
-
buildPartial
public Public.PredictionInstanceSegmentationPolygon buildPartial()
- Specified by:
buildPartialin interfacecom.google.protobuf.Message.Builder- Specified by:
buildPartialin interfacecom.google.protobuf.MessageLite.Builder
-
clone
public Public.PredictionInstanceSegmentationPolygon.Builder clone()
- Specified by:
clonein interfacecom.google.protobuf.Message.Builder- Specified by:
clonein interfacecom.google.protobuf.MessageLite.Builder- Overrides:
clonein classcom.google.protobuf.GeneratedMessageV3.Builder<Public.PredictionInstanceSegmentationPolygon.Builder>
-
setField
public Public.PredictionInstanceSegmentationPolygon.Builder setField(com.google.protobuf.Descriptors.FieldDescriptor field, Object value)
- Specified by:
setFieldin interfacecom.google.protobuf.Message.Builder- Overrides:
setFieldin classcom.google.protobuf.GeneratedMessageV3.Builder<Public.PredictionInstanceSegmentationPolygon.Builder>
-
clearField
public Public.PredictionInstanceSegmentationPolygon.Builder clearField(com.google.protobuf.Descriptors.FieldDescriptor field)
- Specified by:
clearFieldin interfacecom.google.protobuf.Message.Builder- Overrides:
clearFieldin classcom.google.protobuf.GeneratedMessageV3.Builder<Public.PredictionInstanceSegmentationPolygon.Builder>
-
clearOneof
public Public.PredictionInstanceSegmentationPolygon.Builder clearOneof(com.google.protobuf.Descriptors.OneofDescriptor oneof)
- Specified by:
clearOneofin interfacecom.google.protobuf.Message.Builder- Overrides:
clearOneofin classcom.google.protobuf.GeneratedMessageV3.Builder<Public.PredictionInstanceSegmentationPolygon.Builder>
-
setRepeatedField
public Public.PredictionInstanceSegmentationPolygon.Builder setRepeatedField(com.google.protobuf.Descriptors.FieldDescriptor field, int index, Object value)
- Specified by:
setRepeatedFieldin interfacecom.google.protobuf.Message.Builder- Overrides:
setRepeatedFieldin classcom.google.protobuf.GeneratedMessageV3.Builder<Public.PredictionInstanceSegmentationPolygon.Builder>
-
addRepeatedField
public Public.PredictionInstanceSegmentationPolygon.Builder addRepeatedField(com.google.protobuf.Descriptors.FieldDescriptor field, Object value)
- Specified by:
addRepeatedFieldin interfacecom.google.protobuf.Message.Builder- Overrides:
addRepeatedFieldin classcom.google.protobuf.GeneratedMessageV3.Builder<Public.PredictionInstanceSegmentationPolygon.Builder>
-
mergeFrom
public Public.PredictionInstanceSegmentationPolygon.Builder mergeFrom(com.google.protobuf.Message other)
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<Public.PredictionInstanceSegmentationPolygon.Builder>
-
mergeFrom
public Public.PredictionInstanceSegmentationPolygon.Builder mergeFrom(Public.PredictionInstanceSegmentationPolygon other)
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessageV3.Builder<Public.PredictionInstanceSegmentationPolygon.Builder>
-
mergeFrom
public Public.PredictionInstanceSegmentationPolygon.Builder mergeFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Specified by:
mergeFromin interfacecom.google.protobuf.Message.Builder- Specified by:
mergeFromin interfacecom.google.protobuf.MessageLite.Builder- Overrides:
mergeFromin classcom.google.protobuf.AbstractMessage.Builder<Public.PredictionInstanceSegmentationPolygon.Builder>- Throws:
IOException
-
getCoordinatesList
public List<Double> getCoordinatesList()
format (x,y,x,y... of vertices)
repeated double coordinates = 1;- Specified by:
getCoordinatesListin interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder- Returns:
- A list containing the coordinates.
-
getCoordinatesCount
public int getCoordinatesCount()
format (x,y,x,y... of vertices)
repeated double coordinates = 1;- Specified by:
getCoordinatesCountin interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder- Returns:
- The count of coordinates.
-
getCoordinates
public double getCoordinates(int index)
format (x,y,x,y... of vertices)
repeated double coordinates = 1;- Specified by:
getCoordinatesin interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder- Parameters:
index- The index of the element to return.- Returns:
- The coordinates at the given index.
-
setCoordinates
public Public.PredictionInstanceSegmentationPolygon.Builder setCoordinates(int index, double value)
format (x,y,x,y... of vertices)
repeated double coordinates = 1;- Parameters:
index- The index to set the value at.value- The coordinates to set.- Returns:
- This builder for chaining.
-
addCoordinates
public Public.PredictionInstanceSegmentationPolygon.Builder addCoordinates(double value)
format (x,y,x,y... of vertices)
repeated double coordinates = 1;- Parameters:
value- The coordinates to add.- Returns:
- This builder for chaining.
-
addAllCoordinates
public Public.PredictionInstanceSegmentationPolygon.Builder addAllCoordinates(Iterable<? extends Double> values)
format (x,y,x,y... of vertices)
repeated double coordinates = 1;- Parameters:
values- The coordinates to add.- Returns:
- This builder for chaining.
-
clearCoordinates
public Public.PredictionInstanceSegmentationPolygon.Builder clearCoordinates()
format (x,y,x,y... of vertices)
repeated double coordinates = 1;- Returns:
- This builder for chaining.
-
getBboxCoordinatesList
public List<Double> getBboxCoordinatesList()
format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixels
repeated double bbox_coordinates = 2;- Specified by:
getBboxCoordinatesListin interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder- Returns:
- A list containing the bboxCoordinates.
-
getBboxCoordinatesCount
public int getBboxCoordinatesCount()
format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixels
repeated double bbox_coordinates = 2;- Specified by:
getBboxCoordinatesCountin interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder- Returns:
- The count of bboxCoordinates.
-
getBboxCoordinates
public double getBboxCoordinates(int index)
format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixels
repeated double bbox_coordinates = 2;- Specified by:
getBboxCoordinatesin interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder- Parameters:
index- The index of the element to return.- Returns:
- The bboxCoordinates at the given index.
-
setBboxCoordinates
public Public.PredictionInstanceSegmentationPolygon.Builder setBboxCoordinates(int index, double value)
format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixels
repeated double bbox_coordinates = 2;- Parameters:
index- The index to set the value at.value- The bboxCoordinates to set.- Returns:
- This builder for chaining.
-
addBboxCoordinates
public Public.PredictionInstanceSegmentationPolygon.Builder addBboxCoordinates(double value)
format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixels
repeated double bbox_coordinates = 2;- Parameters:
value- The bboxCoordinates to add.- Returns:
- This builder for chaining.
-
addAllBboxCoordinates
public Public.PredictionInstanceSegmentationPolygon.Builder addAllBboxCoordinates(Iterable<? extends Double> values)
format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixels
repeated double bbox_coordinates = 2;- Parameters:
values- The bboxCoordinates to add.- Returns:
- This builder for chaining.
-
clearBboxCoordinates
public Public.PredictionInstanceSegmentationPolygon.Builder clearBboxCoordinates()
format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixels
repeated double bbox_coordinates = 2;- Returns:
- This builder for chaining.
-
getCategory
public String getCategory()
string category = 3;- Specified by:
getCategoryin interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder- Returns:
- The category.
-
getCategoryBytes
public com.google.protobuf.ByteString getCategoryBytes()
string category = 3;- Specified by:
getCategoryBytesin interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder- Returns:
- The bytes for category.
-
setCategory
public Public.PredictionInstanceSegmentationPolygon.Builder setCategory(String value)
string category = 3;- Parameters:
value- The category to set.- Returns:
- This builder for chaining.
-
clearCategory
public Public.PredictionInstanceSegmentationPolygon.Builder clearCategory()
string category = 3;- Returns:
- This builder for chaining.
-
setCategoryBytes
public Public.PredictionInstanceSegmentationPolygon.Builder setCategoryBytes(com.google.protobuf.ByteString value)
string category = 3;- Parameters:
value- The bytes for category to set.- Returns:
- This builder for chaining.
-
hasScore
public boolean hasScore()
.google.protobuf.DoubleValue score = 4;- Specified by:
hasScorein interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder- Returns:
- Whether the score field is set.
-
getScore
public com.google.protobuf.DoubleValue getScore()
.google.protobuf.DoubleValue score = 4;- Specified by:
getScorein interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder- Returns:
- The score.
-
setScore
public Public.PredictionInstanceSegmentationPolygon.Builder setScore(com.google.protobuf.DoubleValue value)
.google.protobuf.DoubleValue score = 4;
-
setScore
public Public.PredictionInstanceSegmentationPolygon.Builder setScore(com.google.protobuf.DoubleValue.Builder builderForValue)
.google.protobuf.DoubleValue score = 4;
-
mergeScore
public Public.PredictionInstanceSegmentationPolygon.Builder mergeScore(com.google.protobuf.DoubleValue value)
.google.protobuf.DoubleValue score = 4;
-
clearScore
public Public.PredictionInstanceSegmentationPolygon.Builder clearScore()
.google.protobuf.DoubleValue score = 4;
-
getScoreBuilder
public com.google.protobuf.DoubleValue.Builder getScoreBuilder()
.google.protobuf.DoubleValue score = 4;
-
getScoreOrBuilder
public com.google.protobuf.DoubleValueOrBuilder getScoreOrBuilder()
.google.protobuf.DoubleValue score = 4;- Specified by:
getScoreOrBuilderin interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder
-
setUnknownFields
public final Public.PredictionInstanceSegmentationPolygon.Builder setUnknownFields(com.google.protobuf.UnknownFieldSet unknownFields)
- Specified by:
setUnknownFieldsin interfacecom.google.protobuf.Message.Builder- Overrides:
setUnknownFieldsin classcom.google.protobuf.GeneratedMessageV3.Builder<Public.PredictionInstanceSegmentationPolygon.Builder>
-
mergeUnknownFields
public final Public.PredictionInstanceSegmentationPolygon.Builder mergeUnknownFields(com.google.protobuf.UnknownFieldSet unknownFields)
- Specified by:
mergeUnknownFieldsin interfacecom.google.protobuf.Message.Builder- Overrides:
mergeUnknownFieldsin classcom.google.protobuf.GeneratedMessageV3.Builder<Public.PredictionInstanceSegmentationPolygon.Builder>
-
-