Package com.arize.protocol
Class Public.Schema.DocumentColumnNames
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite
-
- com.google.protobuf.AbstractMessage
-
- com.google.protobuf.GeneratedMessageV3
-
- com.arize.protocol.Public.Schema.DocumentColumnNames
-
- All Implemented Interfaces:
Public.Schema.DocumentColumnNamesOrBuilder,com.google.protobuf.Message,com.google.protobuf.MessageLite,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,Serializable
- Enclosing class:
- Public.Schema
public static final class Public.Schema.DocumentColumnNames extends com.google.protobuf.GeneratedMessageV3 implements Public.Schema.DocumentColumnNamesOrBuilder
Protobuf typepublic.Schema.DocumentColumnNames- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classPublic.Schema.DocumentColumnNames.BuilderProtobuf typepublic.Schema.DocumentColumnNames-
Nested classes/interfaces inherited from class com.google.protobuf.GeneratedMessageV3
com.google.protobuf.GeneratedMessageV3.BuilderParent, com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>,BuilderT extends com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT,BuilderT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessageOrBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.FieldAccessorTable, com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter
-
-
Field Summary
Fields Modifier and Type Field Description static intID_COLUMN_NAME_FIELD_NUMBERstatic intTEXT_COLUMN_NAME_FIELD_NUMBERstatic intVERSION_COLUMN_NAME_FIELD_NUMBER
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(Object obj)static Public.Schema.DocumentColumnNamesgetDefaultInstance()Public.Schema.DocumentColumnNamesgetDefaultInstanceForType()static com.google.protobuf.Descriptors.DescriptorgetDescriptor()StringgetIdColumnName()string id_column_name = 1;com.google.protobuf.ByteStringgetIdColumnNameBytes()string id_column_name = 1;com.google.protobuf.Parser<Public.Schema.DocumentColumnNames>getParserForType()intgetSerializedSize()Public.Schema.EmbeddingColumnNamesgetTextColumnName().public.Schema.EmbeddingColumnNames text_column_name = 2;Public.Schema.EmbeddingColumnNamesOrBuildergetTextColumnNameOrBuilder().public.Schema.EmbeddingColumnNames text_column_name = 2;com.google.protobuf.UnknownFieldSetgetUnknownFields()StringgetVersionColumnName()string version_column_name = 3;com.google.protobuf.ByteStringgetVersionColumnNameBytes()string version_column_name = 3;inthashCode()booleanhasTextColumnName().public.Schema.EmbeddingColumnNames text_column_name = 2;protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTableinternalGetFieldAccessorTable()booleanisInitialized()static Public.Schema.DocumentColumnNames.BuildernewBuilder()static Public.Schema.DocumentColumnNames.BuildernewBuilder(Public.Schema.DocumentColumnNames prototype)Public.Schema.DocumentColumnNames.BuildernewBuilderForType()protected Public.Schema.DocumentColumnNames.BuildernewBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)protected ObjectnewInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)static Public.Schema.DocumentColumnNamesparseDelimitedFrom(InputStream input)static Public.Schema.DocumentColumnNamesparseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.Schema.DocumentColumnNamesparseFrom(byte[] data)static Public.Schema.DocumentColumnNamesparseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.Schema.DocumentColumnNamesparseFrom(com.google.protobuf.ByteString data)static Public.Schema.DocumentColumnNamesparseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.Schema.DocumentColumnNamesparseFrom(com.google.protobuf.CodedInputStream input)static Public.Schema.DocumentColumnNamesparseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.Schema.DocumentColumnNamesparseFrom(InputStream input)static Public.Schema.DocumentColumnNamesparseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.Schema.DocumentColumnNamesparseFrom(ByteBuffer data)static Public.Schema.DocumentColumnNamesparseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static com.google.protobuf.Parser<Public.Schema.DocumentColumnNames>parser()Public.Schema.DocumentColumnNames.BuildertoBuilder()voidwriteTo(com.google.protobuf.CodedOutputStream output)-
Methods inherited from class com.google.protobuf.GeneratedMessageV3
canUseUnsafe, computeStringSize, computeStringSizeNoTag, emptyBooleanList, emptyDoubleList, emptyFloatList, emptyIntList, emptyList, emptyLongList, getAllFields, getDescriptorForType, getField, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, isStringEmpty, makeExtensionsImmutable, makeMutableCopy, makeMutableCopy, mergeFromAndMakeImmutableInternal, mutableCopy, mutableCopy, mutableCopy, mutableCopy, mutableCopy, newBooleanList, newBuilderForType, newDoubleList, newFloatList, newIntList, newLongList, parseDelimitedWithIOException, parseDelimitedWithIOException, parseUnknownField, parseUnknownFieldProto3, parseWithIOException, parseWithIOException, parseWithIOException, parseWithIOException, serializeBooleanMapTo, serializeIntegerMapTo, serializeLongMapTo, serializeStringMapTo, writeReplace, writeString, writeStringNoTag
-
Methods inherited from class com.google.protobuf.AbstractMessage
findInitializationErrors, getInitializationErrorString, hashBoolean, hashEnum, hashEnumList, hashFields, hashLong, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite
addAll, addAll, checkByteStringIsUtf8, toByteArray, toByteString, writeDelimitedTo, writeTo
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
-
-
-
Field Detail
-
ID_COLUMN_NAME_FIELD_NUMBER
public static final int ID_COLUMN_NAME_FIELD_NUMBER
- See Also:
- Constant Field Values
-
TEXT_COLUMN_NAME_FIELD_NUMBER
public static final int TEXT_COLUMN_NAME_FIELD_NUMBER
- See Also:
- Constant Field Values
-
VERSION_COLUMN_NAME_FIELD_NUMBER
public static final int VERSION_COLUMN_NAME_FIELD_NUMBER
- See Also:
- Constant Field Values
-
-
Method Detail
-
newInstance
protected Object newInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)
- Overrides:
newInstancein classcom.google.protobuf.GeneratedMessageV3
-
getUnknownFields
public final com.google.protobuf.UnknownFieldSet getUnknownFields()
- Specified by:
getUnknownFieldsin interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getUnknownFieldsin classcom.google.protobuf.GeneratedMessageV3
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessageV3
-
getIdColumnName
public String getIdColumnName()
string id_column_name = 1;- Specified by:
getIdColumnNamein interfacePublic.Schema.DocumentColumnNamesOrBuilder- Returns:
- The idColumnName.
-
getIdColumnNameBytes
public com.google.protobuf.ByteString getIdColumnNameBytes()
string id_column_name = 1;- Specified by:
getIdColumnNameBytesin interfacePublic.Schema.DocumentColumnNamesOrBuilder- Returns:
- The bytes for idColumnName.
-
hasTextColumnName
public boolean hasTextColumnName()
.public.Schema.EmbeddingColumnNames text_column_name = 2;- Specified by:
hasTextColumnNamein interfacePublic.Schema.DocumentColumnNamesOrBuilder- Returns:
- Whether the textColumnName field is set.
-
getTextColumnName
public Public.Schema.EmbeddingColumnNames getTextColumnName()
.public.Schema.EmbeddingColumnNames text_column_name = 2;- Specified by:
getTextColumnNamein interfacePublic.Schema.DocumentColumnNamesOrBuilder- Returns:
- The textColumnName.
-
getTextColumnNameOrBuilder
public Public.Schema.EmbeddingColumnNamesOrBuilder getTextColumnNameOrBuilder()
.public.Schema.EmbeddingColumnNames text_column_name = 2;- Specified by:
getTextColumnNameOrBuilderin interfacePublic.Schema.DocumentColumnNamesOrBuilder
-
getVersionColumnName
public String getVersionColumnName()
string version_column_name = 3;- Specified by:
getVersionColumnNamein interfacePublic.Schema.DocumentColumnNamesOrBuilder- Returns:
- The versionColumnName.
-
getVersionColumnNameBytes
public com.google.protobuf.ByteString getVersionColumnNameBytes()
string version_column_name = 3;- Specified by:
getVersionColumnNameBytesin interfacePublic.Schema.DocumentColumnNamesOrBuilder- Returns:
- The bytes for versionColumnName.
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessageV3
-
writeTo
public void writeTo(com.google.protobuf.CodedOutputStream output) throws IOException- Specified by:
writeToin interfacecom.google.protobuf.MessageLite- Overrides:
writeToin classcom.google.protobuf.GeneratedMessageV3- Throws:
IOException
-
getSerializedSize
public int getSerializedSize()
- Specified by:
getSerializedSizein interfacecom.google.protobuf.MessageLite- Overrides:
getSerializedSizein classcom.google.protobuf.GeneratedMessageV3
-
equals
public boolean equals(Object obj)
- Specified by:
equalsin interfacecom.google.protobuf.Message- Overrides:
equalsin classcom.google.protobuf.AbstractMessage
-
hashCode
public int hashCode()
- Specified by:
hashCodein interfacecom.google.protobuf.Message- Overrides:
hashCodein classcom.google.protobuf.AbstractMessage
-
parseFrom
public static Public.Schema.DocumentColumnNames parseFrom(ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.Schema.DocumentColumnNames parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.Schema.DocumentColumnNames parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.Schema.DocumentColumnNames parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.Schema.DocumentColumnNames parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.Schema.DocumentColumnNames parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.Schema.DocumentColumnNames parseFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.Schema.DocumentColumnNames parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.Schema.DocumentColumnNames parseDelimitedFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.Schema.DocumentColumnNames parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.Schema.DocumentColumnNames parseFrom(com.google.protobuf.CodedInputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.Schema.DocumentColumnNames parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
newBuilderForType
public Public.Schema.DocumentColumnNames.Builder newBuilderForType()
- Specified by:
newBuilderForTypein interfacecom.google.protobuf.Message- Specified by:
newBuilderForTypein interfacecom.google.protobuf.MessageLite
-
newBuilder
public static Public.Schema.DocumentColumnNames.Builder newBuilder()
-
newBuilder
public static Public.Schema.DocumentColumnNames.Builder newBuilder(Public.Schema.DocumentColumnNames prototype)
-
toBuilder
public Public.Schema.DocumentColumnNames.Builder toBuilder()
- Specified by:
toBuilderin interfacecom.google.protobuf.Message- Specified by:
toBuilderin interfacecom.google.protobuf.MessageLite
-
newBuilderForType
protected Public.Schema.DocumentColumnNames.Builder newBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)
- Specified by:
newBuilderForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstance
public static Public.Schema.DocumentColumnNames getDefaultInstance()
-
parser
public static com.google.protobuf.Parser<Public.Schema.DocumentColumnNames> parser()
-
getParserForType
public com.google.protobuf.Parser<Public.Schema.DocumentColumnNames> getParserForType()
- Specified by:
getParserForTypein interfacecom.google.protobuf.Message- Specified by:
getParserForTypein interfacecom.google.protobuf.MessageLite- Overrides:
getParserForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstanceForType
public Public.Schema.DocumentColumnNames getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
-