Package com.arize.protocol
Class Public.Schema.EmbeddingColumnNames
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite
-
- com.google.protobuf.AbstractMessage
-
- com.google.protobuf.GeneratedMessageV3
-
- com.arize.protocol.Public.Schema.EmbeddingColumnNames
-
- All Implemented Interfaces:
Public.Schema.EmbeddingColumnNamesOrBuilder,com.google.protobuf.Message,com.google.protobuf.MessageLite,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,Serializable
- Enclosing class:
- Public.Schema
public static final class Public.Schema.EmbeddingColumnNames extends com.google.protobuf.GeneratedMessageV3 implements Public.Schema.EmbeddingColumnNamesOrBuilder
Protobuf typepublic.Schema.EmbeddingColumnNames- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classPublic.Schema.EmbeddingColumnNames.BuilderProtobuf typepublic.Schema.EmbeddingColumnNames-
Nested classes/interfaces inherited from class com.google.protobuf.GeneratedMessageV3
com.google.protobuf.GeneratedMessageV3.BuilderParent, com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>,BuilderT extends com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT,BuilderT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessageOrBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.FieldAccessorTable, com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter
-
-
Field Summary
Fields Modifier and Type Field Description static intDATA_COLUMN_NAME_FIELD_NUMBERstatic intLINK_TO_DATA_COLUMN_NAME_FIELD_NUMBERstatic intVECTOR_COLUMN_NAME_FIELD_NUMBER
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(Object obj)StringgetDataColumnName()string data_column_name = 2;com.google.protobuf.ByteStringgetDataColumnNameBytes()string data_column_name = 2;static Public.Schema.EmbeddingColumnNamesgetDefaultInstance()Public.Schema.EmbeddingColumnNamesgetDefaultInstanceForType()static com.google.protobuf.Descriptors.DescriptorgetDescriptor()StringgetLinkToDataColumnName()string link_to_data_column_name = 3;com.google.protobuf.ByteStringgetLinkToDataColumnNameBytes()string link_to_data_column_name = 3;com.google.protobuf.Parser<Public.Schema.EmbeddingColumnNames>getParserForType()intgetSerializedSize()com.google.protobuf.UnknownFieldSetgetUnknownFields()StringgetVectorColumnName()string vector_column_name = 1;com.google.protobuf.ByteStringgetVectorColumnNameBytes()string vector_column_name = 1;inthashCode()protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTableinternalGetFieldAccessorTable()booleanisInitialized()static Public.Schema.EmbeddingColumnNames.BuildernewBuilder()static Public.Schema.EmbeddingColumnNames.BuildernewBuilder(Public.Schema.EmbeddingColumnNames prototype)Public.Schema.EmbeddingColumnNames.BuildernewBuilderForType()protected Public.Schema.EmbeddingColumnNames.BuildernewBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)protected ObjectnewInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)static Public.Schema.EmbeddingColumnNamesparseDelimitedFrom(InputStream input)static Public.Schema.EmbeddingColumnNamesparseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.Schema.EmbeddingColumnNamesparseFrom(byte[] data)static Public.Schema.EmbeddingColumnNamesparseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.Schema.EmbeddingColumnNamesparseFrom(com.google.protobuf.ByteString data)static Public.Schema.EmbeddingColumnNamesparseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.Schema.EmbeddingColumnNamesparseFrom(com.google.protobuf.CodedInputStream input)static Public.Schema.EmbeddingColumnNamesparseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.Schema.EmbeddingColumnNamesparseFrom(InputStream input)static Public.Schema.EmbeddingColumnNamesparseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.Schema.EmbeddingColumnNamesparseFrom(ByteBuffer data)static Public.Schema.EmbeddingColumnNamesparseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static com.google.protobuf.Parser<Public.Schema.EmbeddingColumnNames>parser()Public.Schema.EmbeddingColumnNames.BuildertoBuilder()voidwriteTo(com.google.protobuf.CodedOutputStream output)-
Methods inherited from class com.google.protobuf.GeneratedMessageV3
canUseUnsafe, computeStringSize, computeStringSizeNoTag, emptyBooleanList, emptyDoubleList, emptyFloatList, emptyIntList, emptyList, emptyLongList, getAllFields, getDescriptorForType, getField, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, isStringEmpty, makeExtensionsImmutable, makeMutableCopy, makeMutableCopy, mergeFromAndMakeImmutableInternal, mutableCopy, mutableCopy, mutableCopy, mutableCopy, mutableCopy, newBooleanList, newBuilderForType, newDoubleList, newFloatList, newIntList, newLongList, parseDelimitedWithIOException, parseDelimitedWithIOException, parseUnknownField, parseUnknownFieldProto3, parseWithIOException, parseWithIOException, parseWithIOException, parseWithIOException, serializeBooleanMapTo, serializeIntegerMapTo, serializeLongMapTo, serializeStringMapTo, writeReplace, writeString, writeStringNoTag
-
Methods inherited from class com.google.protobuf.AbstractMessage
findInitializationErrors, getInitializationErrorString, hashBoolean, hashEnum, hashEnumList, hashFields, hashLong, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite
addAll, addAll, checkByteStringIsUtf8, toByteArray, toByteString, writeDelimitedTo, writeTo
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
-
-
-
Field Detail
-
VECTOR_COLUMN_NAME_FIELD_NUMBER
public static final int VECTOR_COLUMN_NAME_FIELD_NUMBER
- See Also:
- Constant Field Values
-
DATA_COLUMN_NAME_FIELD_NUMBER
public static final int DATA_COLUMN_NAME_FIELD_NUMBER
- See Also:
- Constant Field Values
-
LINK_TO_DATA_COLUMN_NAME_FIELD_NUMBER
public static final int LINK_TO_DATA_COLUMN_NAME_FIELD_NUMBER
- See Also:
- Constant Field Values
-
-
Method Detail
-
newInstance
protected Object newInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)
- Overrides:
newInstancein classcom.google.protobuf.GeneratedMessageV3
-
getUnknownFields
public final com.google.protobuf.UnknownFieldSet getUnknownFields()
- Specified by:
getUnknownFieldsin interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getUnknownFieldsin classcom.google.protobuf.GeneratedMessageV3
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessageV3
-
getVectorColumnName
public String getVectorColumnName()
string vector_column_name = 1;- Specified by:
getVectorColumnNamein interfacePublic.Schema.EmbeddingColumnNamesOrBuilder- Returns:
- The vectorColumnName.
-
getVectorColumnNameBytes
public com.google.protobuf.ByteString getVectorColumnNameBytes()
string vector_column_name = 1;- Specified by:
getVectorColumnNameBytesin interfacePublic.Schema.EmbeddingColumnNamesOrBuilder- Returns:
- The bytes for vectorColumnName.
-
getDataColumnName
public String getDataColumnName()
string data_column_name = 2;- Specified by:
getDataColumnNamein interfacePublic.Schema.EmbeddingColumnNamesOrBuilder- Returns:
- The dataColumnName.
-
getDataColumnNameBytes
public com.google.protobuf.ByteString getDataColumnNameBytes()
string data_column_name = 2;- Specified by:
getDataColumnNameBytesin interfacePublic.Schema.EmbeddingColumnNamesOrBuilder- Returns:
- The bytes for dataColumnName.
-
getLinkToDataColumnName
public String getLinkToDataColumnName()
string link_to_data_column_name = 3;- Specified by:
getLinkToDataColumnNamein interfacePublic.Schema.EmbeddingColumnNamesOrBuilder- Returns:
- The linkToDataColumnName.
-
getLinkToDataColumnNameBytes
public com.google.protobuf.ByteString getLinkToDataColumnNameBytes()
string link_to_data_column_name = 3;- Specified by:
getLinkToDataColumnNameBytesin interfacePublic.Schema.EmbeddingColumnNamesOrBuilder- Returns:
- The bytes for linkToDataColumnName.
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessageV3
-
writeTo
public void writeTo(com.google.protobuf.CodedOutputStream output) throws IOException- Specified by:
writeToin interfacecom.google.protobuf.MessageLite- Overrides:
writeToin classcom.google.protobuf.GeneratedMessageV3- Throws:
IOException
-
getSerializedSize
public int getSerializedSize()
- Specified by:
getSerializedSizein interfacecom.google.protobuf.MessageLite- Overrides:
getSerializedSizein classcom.google.protobuf.GeneratedMessageV3
-
equals
public boolean equals(Object obj)
- Specified by:
equalsin interfacecom.google.protobuf.Message- Overrides:
equalsin classcom.google.protobuf.AbstractMessage
-
hashCode
public int hashCode()
- Specified by:
hashCodein interfacecom.google.protobuf.Message- Overrides:
hashCodein classcom.google.protobuf.AbstractMessage
-
parseFrom
public static Public.Schema.EmbeddingColumnNames parseFrom(ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.Schema.EmbeddingColumnNames parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.Schema.EmbeddingColumnNames parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.Schema.EmbeddingColumnNames parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.Schema.EmbeddingColumnNames parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.Schema.EmbeddingColumnNames parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.Schema.EmbeddingColumnNames parseFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.Schema.EmbeddingColumnNames parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.Schema.EmbeddingColumnNames parseDelimitedFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.Schema.EmbeddingColumnNames parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.Schema.EmbeddingColumnNames parseFrom(com.google.protobuf.CodedInputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.Schema.EmbeddingColumnNames parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
newBuilderForType
public Public.Schema.EmbeddingColumnNames.Builder newBuilderForType()
- Specified by:
newBuilderForTypein interfacecom.google.protobuf.Message- Specified by:
newBuilderForTypein interfacecom.google.protobuf.MessageLite
-
newBuilder
public static Public.Schema.EmbeddingColumnNames.Builder newBuilder()
-
newBuilder
public static Public.Schema.EmbeddingColumnNames.Builder newBuilder(Public.Schema.EmbeddingColumnNames prototype)
-
toBuilder
public Public.Schema.EmbeddingColumnNames.Builder toBuilder()
- Specified by:
toBuilderin interfacecom.google.protobuf.Message- Specified by:
toBuilderin interfacecom.google.protobuf.MessageLite
-
newBuilderForType
protected Public.Schema.EmbeddingColumnNames.Builder newBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)
- Specified by:
newBuilderForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstance
public static Public.Schema.EmbeddingColumnNames getDefaultInstance()
-
parser
public static com.google.protobuf.Parser<Public.Schema.EmbeddingColumnNames> parser()
-
getParserForType
public com.google.protobuf.Parser<Public.Schema.EmbeddingColumnNames> getParserForType()
- Specified by:
getParserForTypein interfacecom.google.protobuf.Message- Specified by:
getParserForTypein interfacecom.google.protobuf.MessageLite- Overrides:
getParserForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstanceForType
public Public.Schema.EmbeddingColumnNames getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
-