Package com.arize.protocol
Class Public.Schema.LLMConfigColumnNames
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite
-
- com.google.protobuf.AbstractMessage
-
- com.google.protobuf.GeneratedMessageV3
-
- com.arize.protocol.Public.Schema.LLMConfigColumnNames
-
- All Implemented Interfaces:
Public.Schema.LLMConfigColumnNamesOrBuilder,com.google.protobuf.Message,com.google.protobuf.MessageLite,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,Serializable
- Enclosing class:
- Public.Schema
public static final class Public.Schema.LLMConfigColumnNames extends com.google.protobuf.GeneratedMessageV3 implements Public.Schema.LLMConfigColumnNamesOrBuilder
Protobuf typepublic.Schema.LLMConfigColumnNames- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classPublic.Schema.LLMConfigColumnNames.BuilderProtobuf typepublic.Schema.LLMConfigColumnNames-
Nested classes/interfaces inherited from class com.google.protobuf.GeneratedMessageV3
com.google.protobuf.GeneratedMessageV3.BuilderParent, com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>,BuilderT extends com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT,BuilderT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessageOrBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.FieldAccessorTable, com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter
-
-
Field Summary
Fields Modifier and Type Field Description static intMODEL_COLUMN_NAME_FIELD_NUMBERstatic intPARAMS_MAP_COLUMN_NAME_FIELD_NUMBER
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(Object obj)static Public.Schema.LLMConfigColumnNamesgetDefaultInstance()Public.Schema.LLMConfigColumnNamesgetDefaultInstanceForType()static com.google.protobuf.Descriptors.DescriptorgetDescriptor()StringgetModelColumnName()string model_column_name = 1;com.google.protobuf.ByteStringgetModelColumnNameBytes()string model_column_name = 1;StringgetParamsMapColumnName()string params_map_column_name = 2;com.google.protobuf.ByteStringgetParamsMapColumnNameBytes()string params_map_column_name = 2;com.google.protobuf.Parser<Public.Schema.LLMConfigColumnNames>getParserForType()intgetSerializedSize()com.google.protobuf.UnknownFieldSetgetUnknownFields()inthashCode()protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTableinternalGetFieldAccessorTable()booleanisInitialized()static Public.Schema.LLMConfigColumnNames.BuildernewBuilder()static Public.Schema.LLMConfigColumnNames.BuildernewBuilder(Public.Schema.LLMConfigColumnNames prototype)Public.Schema.LLMConfigColumnNames.BuildernewBuilderForType()protected Public.Schema.LLMConfigColumnNames.BuildernewBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)protected ObjectnewInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)static Public.Schema.LLMConfigColumnNamesparseDelimitedFrom(InputStream input)static Public.Schema.LLMConfigColumnNamesparseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.Schema.LLMConfigColumnNamesparseFrom(byte[] data)static Public.Schema.LLMConfigColumnNamesparseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.Schema.LLMConfigColumnNamesparseFrom(com.google.protobuf.ByteString data)static Public.Schema.LLMConfigColumnNamesparseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.Schema.LLMConfigColumnNamesparseFrom(com.google.protobuf.CodedInputStream input)static Public.Schema.LLMConfigColumnNamesparseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.Schema.LLMConfigColumnNamesparseFrom(InputStream input)static Public.Schema.LLMConfigColumnNamesparseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.Schema.LLMConfigColumnNamesparseFrom(ByteBuffer data)static Public.Schema.LLMConfigColumnNamesparseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static com.google.protobuf.Parser<Public.Schema.LLMConfigColumnNames>parser()Public.Schema.LLMConfigColumnNames.BuildertoBuilder()voidwriteTo(com.google.protobuf.CodedOutputStream output)-
Methods inherited from class com.google.protobuf.GeneratedMessageV3
canUseUnsafe, computeStringSize, computeStringSizeNoTag, emptyBooleanList, emptyDoubleList, emptyFloatList, emptyIntList, emptyList, emptyLongList, getAllFields, getDescriptorForType, getField, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, isStringEmpty, makeExtensionsImmutable, makeMutableCopy, makeMutableCopy, mergeFromAndMakeImmutableInternal, mutableCopy, mutableCopy, mutableCopy, mutableCopy, mutableCopy, newBooleanList, newBuilderForType, newDoubleList, newFloatList, newIntList, newLongList, parseDelimitedWithIOException, parseDelimitedWithIOException, parseUnknownField, parseUnknownFieldProto3, parseWithIOException, parseWithIOException, parseWithIOException, parseWithIOException, serializeBooleanMapTo, serializeIntegerMapTo, serializeLongMapTo, serializeStringMapTo, writeReplace, writeString, writeStringNoTag
-
Methods inherited from class com.google.protobuf.AbstractMessage
findInitializationErrors, getInitializationErrorString, hashBoolean, hashEnum, hashEnumList, hashFields, hashLong, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite
addAll, addAll, checkByteStringIsUtf8, toByteArray, toByteString, writeDelimitedTo, writeTo
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
-
-
-
Field Detail
-
MODEL_COLUMN_NAME_FIELD_NUMBER
public static final int MODEL_COLUMN_NAME_FIELD_NUMBER
- See Also:
- Constant Field Values
-
PARAMS_MAP_COLUMN_NAME_FIELD_NUMBER
public static final int PARAMS_MAP_COLUMN_NAME_FIELD_NUMBER
- See Also:
- Constant Field Values
-
-
Method Detail
-
newInstance
protected Object newInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)
- Overrides:
newInstancein classcom.google.protobuf.GeneratedMessageV3
-
getUnknownFields
public final com.google.protobuf.UnknownFieldSet getUnknownFields()
- Specified by:
getUnknownFieldsin interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getUnknownFieldsin classcom.google.protobuf.GeneratedMessageV3
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessageV3
-
getModelColumnName
public String getModelColumnName()
string model_column_name = 1;- Specified by:
getModelColumnNamein interfacePublic.Schema.LLMConfigColumnNamesOrBuilder- Returns:
- The modelColumnName.
-
getModelColumnNameBytes
public com.google.protobuf.ByteString getModelColumnNameBytes()
string model_column_name = 1;- Specified by:
getModelColumnNameBytesin interfacePublic.Schema.LLMConfigColumnNamesOrBuilder- Returns:
- The bytes for modelColumnName.
-
getParamsMapColumnName
public String getParamsMapColumnName()
string params_map_column_name = 2;- Specified by:
getParamsMapColumnNamein interfacePublic.Schema.LLMConfigColumnNamesOrBuilder- Returns:
- The paramsMapColumnName.
-
getParamsMapColumnNameBytes
public com.google.protobuf.ByteString getParamsMapColumnNameBytes()
string params_map_column_name = 2;- Specified by:
getParamsMapColumnNameBytesin interfacePublic.Schema.LLMConfigColumnNamesOrBuilder- Returns:
- The bytes for paramsMapColumnName.
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessageV3
-
writeTo
public void writeTo(com.google.protobuf.CodedOutputStream output) throws IOException- Specified by:
writeToin interfacecom.google.protobuf.MessageLite- Overrides:
writeToin classcom.google.protobuf.GeneratedMessageV3- Throws:
IOException
-
getSerializedSize
public int getSerializedSize()
- Specified by:
getSerializedSizein interfacecom.google.protobuf.MessageLite- Overrides:
getSerializedSizein classcom.google.protobuf.GeneratedMessageV3
-
equals
public boolean equals(Object obj)
- Specified by:
equalsin interfacecom.google.protobuf.Message- Overrides:
equalsin classcom.google.protobuf.AbstractMessage
-
hashCode
public int hashCode()
- Specified by:
hashCodein interfacecom.google.protobuf.Message- Overrides:
hashCodein classcom.google.protobuf.AbstractMessage
-
parseFrom
public static Public.Schema.LLMConfigColumnNames parseFrom(ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.Schema.LLMConfigColumnNames parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.Schema.LLMConfigColumnNames parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.Schema.LLMConfigColumnNames parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.Schema.LLMConfigColumnNames parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.Schema.LLMConfigColumnNames parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.Schema.LLMConfigColumnNames parseFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.Schema.LLMConfigColumnNames parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.Schema.LLMConfigColumnNames parseDelimitedFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.Schema.LLMConfigColumnNames parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.Schema.LLMConfigColumnNames parseFrom(com.google.protobuf.CodedInputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.Schema.LLMConfigColumnNames parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
newBuilderForType
public Public.Schema.LLMConfigColumnNames.Builder newBuilderForType()
- Specified by:
newBuilderForTypein interfacecom.google.protobuf.Message- Specified by:
newBuilderForTypein interfacecom.google.protobuf.MessageLite
-
newBuilder
public static Public.Schema.LLMConfigColumnNames.Builder newBuilder()
-
newBuilder
public static Public.Schema.LLMConfigColumnNames.Builder newBuilder(Public.Schema.LLMConfigColumnNames prototype)
-
toBuilder
public Public.Schema.LLMConfigColumnNames.Builder toBuilder()
- Specified by:
toBuilderin interfacecom.google.protobuf.Message- Specified by:
toBuilderin interfacecom.google.protobuf.MessageLite
-
newBuilderForType
protected Public.Schema.LLMConfigColumnNames.Builder newBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)
- Specified by:
newBuilderForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstance
public static Public.Schema.LLMConfigColumnNames getDefaultInstance()
-
parser
public static com.google.protobuf.Parser<Public.Schema.LLMConfigColumnNames> parser()
-
getParserForType
public com.google.protobuf.Parser<Public.Schema.LLMConfigColumnNames> getParserForType()
- Specified by:
getParserForTypein interfacecom.google.protobuf.Message- Specified by:
getParserForTypein interfacecom.google.protobuf.MessageLite- Overrides:
getParserForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstanceForType
public Public.Schema.LLMConfigColumnNames getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
-