Enum Public.Schema.ModelType

    • Field Detail

      • UNKNOWN_MODELTYPE_VALUE

        public static final int UNKNOWN_MODELTYPE_VALUE
        UNKNOWN_MODELTYPE = 0;
        See Also:
        Constant Field Values
      • CATEGORICAL_VALUE

        public static final int CATEGORICAL_VALUE
        CATEGORICAL = 3;
        See Also:
        Constant Field Values
      • SCORE_CATEGORICAL_VALUE

        public static final int SCORE_CATEGORICAL_VALUE
        SCORE_CATEGORICAL = 4;
        See Also:
        Constant Field Values
      • OBJECT_DETECTION_VALUE

        public static final int OBJECT_DETECTION_VALUE
        OBJECT_DETECTION = 6;
        See Also:
        Constant Field Values
      • GENERATIVE_LLM_VALUE

        public static final int GENERATIVE_LLM_VALUE
        GENERATIVE_LLM = 7;
        See Also:
        Constant Field Values
      • MULTI_CLASS_VALUE

        public static final int MULTI_CLASS_VALUE
        MULTI_CLASS = 8;
        See Also:
        Constant Field Values
    • Method Detail

      • values

        public static Public.Schema.ModelType[] values()
        Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:
        for (Public.Schema.ModelType c : Public.Schema.ModelType.values())
            System.out.println(c);
        
        Returns:
        an array containing the constants of this enum type, in the order they are declared
      • valueOf

        public static Public.Schema.ModelType valueOf​(String name)
        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
        Parameters:
        name - the name of the enum constant to be returned.
        Returns:
        the enum constant with the specified name
        Throws:
        IllegalArgumentException - if this enum type has no constant with the specified name
        NullPointerException - if the argument is null
      • getNumber

        public final int getNumber()
        Specified by:
        getNumber in interface com.google.protobuf.Internal.EnumLite
        Specified by:
        getNumber in interface com.google.protobuf.ProtocolMessageEnum
      • valueOf

        @Deprecated
        public static Public.Schema.ModelType valueOf​(int value)
        Deprecated.
        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
        Parameters:
        value - the name of the enum constant to be returned.
        Returns:
        the enum constant with the specified name
        Throws:
        IllegalArgumentException - if this enum type has no constant with the specified name
        NullPointerException - if the argument is null
      • forNumber

        public static Public.Schema.ModelType forNumber​(int value)
        Parameters:
        value - The numeric wire value of the corresponding enum entry.
        Returns:
        The enum associated with the given numeric wire value.
      • internalGetValueMap

        public static com.google.protobuf.Internal.EnumLiteMap<Public.Schema.ModelType> internalGetValueMap()
      • getValueDescriptor

        public final com.google.protobuf.Descriptors.EnumValueDescriptor getValueDescriptor()
        Specified by:
        getValueDescriptor in interface com.google.protobuf.ProtocolMessageEnum
      • getDescriptorForType

        public final com.google.protobuf.Descriptors.EnumDescriptor getDescriptorForType()
        Specified by:
        getDescriptorForType in interface com.google.protobuf.ProtocolMessageEnum
      • getDescriptor

        public static final com.google.protobuf.Descriptors.EnumDescriptor getDescriptor()
      • valueOf

        public static Public.Schema.ModelType valueOf​(com.google.protobuf.Descriptors.EnumValueDescriptor desc)
        Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
        Parameters:
        desc - the name of the enum constant to be returned.
        Returns:
        the enum constant with the specified name
        Throws:
        IllegalArgumentException - if this enum type has no constant with the specified name
        NullPointerException - if the argument is null