Package com.arize.protocol
Class Public.SemanticSegmentationLabel
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite
-
- com.google.protobuf.AbstractMessage
-
- com.google.protobuf.GeneratedMessageV3
-
- com.arize.protocol.Public.SemanticSegmentationLabel
-
- All Implemented Interfaces:
Public.SemanticSegmentationLabelOrBuilder,com.google.protobuf.Message,com.google.protobuf.MessageLite,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,Serializable
- Enclosing class:
- Public
public static final class Public.SemanticSegmentationLabel extends com.google.protobuf.GeneratedMessageV3 implements Public.SemanticSegmentationLabelOrBuilder
SemanticSegmentationLabel contains all the semantic segmentation polygons for either predictions or actuals for a single image.
Protobuf typepublic.SemanticSegmentationLabel- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classPublic.SemanticSegmentationLabel.BuilderSemanticSegmentationLabel contains all the semantic segmentation polygons for either predictions or actuals for a single image.-
Nested classes/interfaces inherited from class com.google.protobuf.GeneratedMessageV3
com.google.protobuf.GeneratedMessageV3.BuilderParent, com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>,BuilderT extends com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT,BuilderT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessageOrBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.FieldAccessorTable, com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter
-
-
Field Summary
Fields Modifier and Type Field Description static intPOLYGONS_FIELD_NUMBER
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(Object obj)static Public.SemanticSegmentationLabelgetDefaultInstance()Public.SemanticSegmentationLabelgetDefaultInstanceForType()static com.google.protobuf.Descriptors.DescriptorgetDescriptor()com.google.protobuf.Parser<Public.SemanticSegmentationLabel>getParserForType()Public.SemanticSegmentationPolygongetPolygons(int index)repeated .public.SemanticSegmentationPolygon polygons = 1;intgetPolygonsCount()repeated .public.SemanticSegmentationPolygon polygons = 1;List<Public.SemanticSegmentationPolygon>getPolygonsList()repeated .public.SemanticSegmentationPolygon polygons = 1;Public.SemanticSegmentationPolygonOrBuildergetPolygonsOrBuilder(int index)repeated .public.SemanticSegmentationPolygon polygons = 1;List<? extends Public.SemanticSegmentationPolygonOrBuilder>getPolygonsOrBuilderList()repeated .public.SemanticSegmentationPolygon polygons = 1;intgetSerializedSize()com.google.protobuf.UnknownFieldSetgetUnknownFields()inthashCode()protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTableinternalGetFieldAccessorTable()booleanisInitialized()static Public.SemanticSegmentationLabel.BuildernewBuilder()static Public.SemanticSegmentationLabel.BuildernewBuilder(Public.SemanticSegmentationLabel prototype)Public.SemanticSegmentationLabel.BuildernewBuilderForType()protected Public.SemanticSegmentationLabel.BuildernewBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)protected ObjectnewInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)static Public.SemanticSegmentationLabelparseDelimitedFrom(InputStream input)static Public.SemanticSegmentationLabelparseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.SemanticSegmentationLabelparseFrom(byte[] data)static Public.SemanticSegmentationLabelparseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.SemanticSegmentationLabelparseFrom(com.google.protobuf.ByteString data)static Public.SemanticSegmentationLabelparseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.SemanticSegmentationLabelparseFrom(com.google.protobuf.CodedInputStream input)static Public.SemanticSegmentationLabelparseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.SemanticSegmentationLabelparseFrom(InputStream input)static Public.SemanticSegmentationLabelparseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.SemanticSegmentationLabelparseFrom(ByteBuffer data)static Public.SemanticSegmentationLabelparseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static com.google.protobuf.Parser<Public.SemanticSegmentationLabel>parser()Public.SemanticSegmentationLabel.BuildertoBuilder()voidwriteTo(com.google.protobuf.CodedOutputStream output)-
Methods inherited from class com.google.protobuf.GeneratedMessageV3
canUseUnsafe, computeStringSize, computeStringSizeNoTag, emptyBooleanList, emptyDoubleList, emptyFloatList, emptyIntList, emptyList, emptyLongList, getAllFields, getDescriptorForType, getField, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, isStringEmpty, makeExtensionsImmutable, makeMutableCopy, makeMutableCopy, mergeFromAndMakeImmutableInternal, mutableCopy, mutableCopy, mutableCopy, mutableCopy, mutableCopy, newBooleanList, newBuilderForType, newDoubleList, newFloatList, newIntList, newLongList, parseDelimitedWithIOException, parseDelimitedWithIOException, parseUnknownField, parseUnknownFieldProto3, parseWithIOException, parseWithIOException, parseWithIOException, parseWithIOException, serializeBooleanMapTo, serializeIntegerMapTo, serializeLongMapTo, serializeStringMapTo, writeReplace, writeString, writeStringNoTag
-
Methods inherited from class com.google.protobuf.AbstractMessage
findInitializationErrors, getInitializationErrorString, hashBoolean, hashEnum, hashEnumList, hashFields, hashLong, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite
addAll, addAll, checkByteStringIsUtf8, toByteArray, toByteString, writeDelimitedTo, writeTo
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
-
-
-
Field Detail
-
POLYGONS_FIELD_NUMBER
public static final int POLYGONS_FIELD_NUMBER
- See Also:
- Constant Field Values
-
-
Method Detail
-
newInstance
protected Object newInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)
- Overrides:
newInstancein classcom.google.protobuf.GeneratedMessageV3
-
getUnknownFields
public final com.google.protobuf.UnknownFieldSet getUnknownFields()
- Specified by:
getUnknownFieldsin interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getUnknownFieldsin classcom.google.protobuf.GeneratedMessageV3
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessageV3
-
getPolygonsList
public List<Public.SemanticSegmentationPolygon> getPolygonsList()
repeated .public.SemanticSegmentationPolygon polygons = 1;- Specified by:
getPolygonsListin interfacePublic.SemanticSegmentationLabelOrBuilder
-
getPolygonsOrBuilderList
public List<? extends Public.SemanticSegmentationPolygonOrBuilder> getPolygonsOrBuilderList()
repeated .public.SemanticSegmentationPolygon polygons = 1;- Specified by:
getPolygonsOrBuilderListin interfacePublic.SemanticSegmentationLabelOrBuilder
-
getPolygonsCount
public int getPolygonsCount()
repeated .public.SemanticSegmentationPolygon polygons = 1;- Specified by:
getPolygonsCountin interfacePublic.SemanticSegmentationLabelOrBuilder
-
getPolygons
public Public.SemanticSegmentationPolygon getPolygons(int index)
repeated .public.SemanticSegmentationPolygon polygons = 1;- Specified by:
getPolygonsin interfacePublic.SemanticSegmentationLabelOrBuilder
-
getPolygonsOrBuilder
public Public.SemanticSegmentationPolygonOrBuilder getPolygonsOrBuilder(int index)
repeated .public.SemanticSegmentationPolygon polygons = 1;- Specified by:
getPolygonsOrBuilderin interfacePublic.SemanticSegmentationLabelOrBuilder
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessageV3
-
writeTo
public void writeTo(com.google.protobuf.CodedOutputStream output) throws IOException- Specified by:
writeToin interfacecom.google.protobuf.MessageLite- Overrides:
writeToin classcom.google.protobuf.GeneratedMessageV3- Throws:
IOException
-
getSerializedSize
public int getSerializedSize()
- Specified by:
getSerializedSizein interfacecom.google.protobuf.MessageLite- Overrides:
getSerializedSizein classcom.google.protobuf.GeneratedMessageV3
-
equals
public boolean equals(Object obj)
- Specified by:
equalsin interfacecom.google.protobuf.Message- Overrides:
equalsin classcom.google.protobuf.AbstractMessage
-
hashCode
public int hashCode()
- Specified by:
hashCodein interfacecom.google.protobuf.Message- Overrides:
hashCodein classcom.google.protobuf.AbstractMessage
-
parseFrom
public static Public.SemanticSegmentationLabel parseFrom(ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.SemanticSegmentationLabel parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.SemanticSegmentationLabel parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.SemanticSegmentationLabel parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.SemanticSegmentationLabel parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.SemanticSegmentationLabel parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.SemanticSegmentationLabel parseFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.SemanticSegmentationLabel parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.SemanticSegmentationLabel parseDelimitedFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.SemanticSegmentationLabel parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.SemanticSegmentationLabel parseFrom(com.google.protobuf.CodedInputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.SemanticSegmentationLabel parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
newBuilderForType
public Public.SemanticSegmentationLabel.Builder newBuilderForType()
- Specified by:
newBuilderForTypein interfacecom.google.protobuf.Message- Specified by:
newBuilderForTypein interfacecom.google.protobuf.MessageLite
-
newBuilder
public static Public.SemanticSegmentationLabel.Builder newBuilder()
-
newBuilder
public static Public.SemanticSegmentationLabel.Builder newBuilder(Public.SemanticSegmentationLabel prototype)
-
toBuilder
public Public.SemanticSegmentationLabel.Builder toBuilder()
- Specified by:
toBuilderin interfacecom.google.protobuf.Message- Specified by:
toBuilderin interfacecom.google.protobuf.MessageLite
-
newBuilderForType
protected Public.SemanticSegmentationLabel.Builder newBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)
- Specified by:
newBuilderForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstance
public static Public.SemanticSegmentationLabel getDefaultInstance()
-
parser
public static com.google.protobuf.Parser<Public.SemanticSegmentationLabel> parser()
-
getParserForType
public com.google.protobuf.Parser<Public.SemanticSegmentationLabel> getParserForType()
- Specified by:
getParserForTypein interfacecom.google.protobuf.Message- Specified by:
getParserForTypein interfacecom.google.protobuf.MessageLite- Overrides:
getParserForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstanceForType
public Public.SemanticSegmentationLabel getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
-