Package com.arize.protocol
Interface Public.UserFileUploadResponseOrBuilder
-
- All Superinterfaces:
com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder
- All Known Implementing Classes:
Public.UserFileUploadResponse,Public.UserFileUploadResponse.Builder
- Enclosing class:
- Public
public static interface Public.UserFileUploadResponseOrBuilder extends com.google.protobuf.MessageOrBuilder
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description StringgetError()error field is set if any error was encountered during the file upload request.com.google.protobuf.ByteStringgetErrorBytes()error field is set if any error was encountered during the file upload request.StringgetFileUuid()string file_uuid = 2;com.google.protobuf.ByteStringgetFileUuidBytes()string file_uuid = 2;-
Methods inherited from interface com.google.protobuf.MessageOrBuilder
findInitializationErrors, getAllFields, getDefaultInstanceForType, getDescriptorForType, getField, getInitializationErrorString, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, getUnknownFields, hasField, hasOneof
-
-
-
-
Method Detail
-
getError
String getError()
error field is set if any error was encountered during the file upload request. If request was successful this field is an empty string
string error = 1;- Returns:
- The error.
-
getErrorBytes
com.google.protobuf.ByteString getErrorBytes()
error field is set if any error was encountered during the file upload request. If request was successful this field is an empty string
string error = 1;- Returns:
- The bytes for error.
-
getFileUuid
String getFileUuid()
string file_uuid = 2;- Returns:
- The fileUuid.
-
getFileUuidBytes
com.google.protobuf.ByteString getFileUuidBytes()
string file_uuid = 2;- Returns:
- The bytes for fileUuid.
-
-