Uses of Interface
com.arize.protocol.Public.Embedding.TokenArrayOrBuilder
-
Packages that use Public.Embedding.TokenArrayOrBuilder Package Description com.arize.protocol -
-
Uses of Public.Embedding.TokenArrayOrBuilder in com.arize.protocol
Classes in com.arize.protocol that implement Public.Embedding.TokenArrayOrBuilder Modifier and Type Class Description static classPublic.Embedding.TokenArrayTokenArray contains list of stringsstatic classPublic.Embedding.TokenArray.BuilderTokenArray contains list of stringsMethods in com.arize.protocol that return Public.Embedding.TokenArrayOrBuilder Modifier and Type Method Description Public.Embedding.TokenArrayOrBuilderPublic.Embedding.RawData.Builder. getTokenArrayOrBuilder()If a token array of only one token is sent, we will infer that it is a piece of text and it will show in the UI as text, not token arrayPublic.Embedding.TokenArrayOrBuilderPublic.Embedding.RawData. getTokenArrayOrBuilder()If a token array of only one token is sent, we will infer that it is a piece of text and it will show in the UI as text, not token arrayPublic.Embedding.TokenArrayOrBuilderPublic.Embedding.RawDataOrBuilder. getTokenArrayOrBuilder()If a token array of only one token is sent, we will infer that it is a piece of text and it will show in the UI as text, not token array
-