Package com.arize.protocol
Class Public.FeatureImportances
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite
-
- com.google.protobuf.AbstractMessage
-
- com.google.protobuf.GeneratedMessageV3
-
- com.arize.protocol.Public.FeatureImportances
-
- All Implemented Interfaces:
Public.FeatureImportancesOrBuilder,com.google.protobuf.Message,com.google.protobuf.MessageLite,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,Serializable
- Enclosing class:
- Public
public static final class Public.FeatureImportances extends com.google.protobuf.GeneratedMessageV3 implements Public.FeatureImportancesOrBuilder
FeatureImportances contains feature importance values for a prediction
Protobuf typepublic.FeatureImportances- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classPublic.FeatureImportances.BuilderFeatureImportances contains feature importance values for a prediction-
Nested classes/interfaces inherited from class com.google.protobuf.GeneratedMessageV3
com.google.protobuf.GeneratedMessageV3.BuilderParent, com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>,BuilderT extends com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT,BuilderT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessageOrBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.FieldAccessorTable, com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter
-
-
Field Summary
Fields Modifier and Type Field Description static intFEATURE_IMPORTANCES_FIELD_NUMBERstatic intMODEL_VERSION_FIELD_NUMBERstatic intTIMESTAMP_FIELD_NUMBER
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Deprecated Methods Modifier and Type Method Description booleancontainsFeatureImportances(String key)importances is a map of human readable model input field containing values that will be used to group together a subset of predictions and feature importance values for a given model_id and model_versionbooleanequals(Object obj)static Public.FeatureImportancesgetDefaultInstance()Public.FeatureImportancesgetDefaultInstanceForType()static com.google.protobuf.Descriptors.DescriptorgetDescriptor()Map<String,Double>getFeatureImportances()Deprecated.intgetFeatureImportancesCount()importances is a map of human readable model input field containing values that will be used to group together a subset of predictions and feature importance values for a given model_id and model_versionMap<String,Double>getFeatureImportancesMap()importances is a map of human readable model input field containing values that will be used to group together a subset of predictions and feature importance values for a given model_id and model_versiondoublegetFeatureImportancesOrDefault(String key, double defaultValue)importances is a map of human readable model input field containing values that will be used to group together a subset of predictions and feature importance values for a given model_id and model_versiondoublegetFeatureImportancesOrThrow(String key)importances is a map of human readable model input field containing values that will be used to group together a subset of predictions and feature importance values for a given model_id and model_versionStringgetModelVersion()model_version is a user-defined field that ensures that the feature importances are generated using the same model version as the prediction for a given model_idcom.google.protobuf.ByteStringgetModelVersionBytes()model_version is a user-defined field that ensures that the feature importances are generated using the same model version as the prediction for a given model_idcom.google.protobuf.Parser<Public.FeatureImportances>getParserForType()intgetSerializedSize()com.google.protobuf.TimestampgetTimestamp()timestamp of the feature importance values request.com.google.protobuf.TimestampOrBuildergetTimestampOrBuilder()timestamp of the feature importance values request.com.google.protobuf.UnknownFieldSetgetUnknownFields()inthashCode()booleanhasTimestamp()timestamp of the feature importance values request.protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTableinternalGetFieldAccessorTable()protected com.google.protobuf.MapFieldinternalGetMapField(int number)booleanisInitialized()static Public.FeatureImportances.BuildernewBuilder()static Public.FeatureImportances.BuildernewBuilder(Public.FeatureImportances prototype)Public.FeatureImportances.BuildernewBuilderForType()protected Public.FeatureImportances.BuildernewBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)protected ObjectnewInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)static Public.FeatureImportancesparseDelimitedFrom(InputStream input)static Public.FeatureImportancesparseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.FeatureImportancesparseFrom(byte[] data)static Public.FeatureImportancesparseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.FeatureImportancesparseFrom(com.google.protobuf.ByteString data)static Public.FeatureImportancesparseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.FeatureImportancesparseFrom(com.google.protobuf.CodedInputStream input)static Public.FeatureImportancesparseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.FeatureImportancesparseFrom(InputStream input)static Public.FeatureImportancesparseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.FeatureImportancesparseFrom(ByteBuffer data)static Public.FeatureImportancesparseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static com.google.protobuf.Parser<Public.FeatureImportances>parser()Public.FeatureImportances.BuildertoBuilder()voidwriteTo(com.google.protobuf.CodedOutputStream output)-
Methods inherited from class com.google.protobuf.GeneratedMessageV3
canUseUnsafe, computeStringSize, computeStringSizeNoTag, emptyBooleanList, emptyDoubleList, emptyFloatList, emptyIntList, emptyList, emptyLongList, getAllFields, getDescriptorForType, getField, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, hasField, hasOneof, internalGetMapFieldReflection, isStringEmpty, makeExtensionsImmutable, makeMutableCopy, makeMutableCopy, mergeFromAndMakeImmutableInternal, mutableCopy, mutableCopy, mutableCopy, mutableCopy, mutableCopy, newBooleanList, newBuilderForType, newDoubleList, newFloatList, newIntList, newLongList, parseDelimitedWithIOException, parseDelimitedWithIOException, parseUnknownField, parseUnknownFieldProto3, parseWithIOException, parseWithIOException, parseWithIOException, parseWithIOException, serializeBooleanMapTo, serializeIntegerMapTo, serializeLongMapTo, serializeStringMapTo, writeReplace, writeString, writeStringNoTag
-
Methods inherited from class com.google.protobuf.AbstractMessage
findInitializationErrors, getInitializationErrorString, hashBoolean, hashEnum, hashEnumList, hashFields, hashLong, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite
addAll, addAll, checkByteStringIsUtf8, toByteArray, toByteString, writeDelimitedTo, writeTo
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
-
-
-
Field Detail
-
TIMESTAMP_FIELD_NUMBER
public static final int TIMESTAMP_FIELD_NUMBER
- See Also:
- Constant Field Values
-
MODEL_VERSION_FIELD_NUMBER
public static final int MODEL_VERSION_FIELD_NUMBER
- See Also:
- Constant Field Values
-
FEATURE_IMPORTANCES_FIELD_NUMBER
public static final int FEATURE_IMPORTANCES_FIELD_NUMBER
- See Also:
- Constant Field Values
-
-
Method Detail
-
newInstance
protected Object newInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)
- Overrides:
newInstancein classcom.google.protobuf.GeneratedMessageV3
-
getUnknownFields
public final com.google.protobuf.UnknownFieldSet getUnknownFields()
- Specified by:
getUnknownFieldsin interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getUnknownFieldsin classcom.google.protobuf.GeneratedMessageV3
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetMapField
protected com.google.protobuf.MapField internalGetMapField(int number)
- Overrides:
internalGetMapFieldin classcom.google.protobuf.GeneratedMessageV3
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessageV3
-
hasTimestamp
public boolean hasTimestamp()
timestamp of the feature importance values request. If not set this will default to the time of receipt
.google.protobuf.Timestamp timestamp = 1;- Specified by:
hasTimestampin interfacePublic.FeatureImportancesOrBuilder- Returns:
- Whether the timestamp field is set.
-
getTimestamp
public com.google.protobuf.Timestamp getTimestamp()
timestamp of the feature importance values request. If not set this will default to the time of receipt
.google.protobuf.Timestamp timestamp = 1;- Specified by:
getTimestampin interfacePublic.FeatureImportancesOrBuilder- Returns:
- The timestamp.
-
getTimestampOrBuilder
public com.google.protobuf.TimestampOrBuilder getTimestampOrBuilder()
timestamp of the feature importance values request. If not set this will default to the time of receipt
.google.protobuf.Timestamp timestamp = 1;- Specified by:
getTimestampOrBuilderin interfacePublic.FeatureImportancesOrBuilder
-
getModelVersion
public String getModelVersion()
model_version is a user-defined field that ensures that the feature importances are generated using the same model version as the prediction for a given model_id
string model_version = 2;- Specified by:
getModelVersionin interfacePublic.FeatureImportancesOrBuilder- Returns:
- The modelVersion.
-
getModelVersionBytes
public com.google.protobuf.ByteString getModelVersionBytes()
model_version is a user-defined field that ensures that the feature importances are generated using the same model version as the prediction for a given model_id
string model_version = 2;- Specified by:
getModelVersionBytesin interfacePublic.FeatureImportancesOrBuilder- Returns:
- The bytes for modelVersion.
-
getFeatureImportancesCount
public int getFeatureImportancesCount()
Description copied from interface:Public.FeatureImportancesOrBuilderimportances is a map of human readable model input field containing values that will be used to group together a subset of predictions and feature importance values for a given model_id and model_version
map<string, double> feature_importances = 3;- Specified by:
getFeatureImportancesCountin interfacePublic.FeatureImportancesOrBuilder
-
containsFeatureImportances
public boolean containsFeatureImportances(String key)
importances is a map of human readable model input field containing values that will be used to group together a subset of predictions and feature importance values for a given model_id and model_version
map<string, double> feature_importances = 3;- Specified by:
containsFeatureImportancesin interfacePublic.FeatureImportancesOrBuilder
-
getFeatureImportances
@Deprecated public Map<String,Double> getFeatureImportances()
Deprecated.UsegetFeatureImportancesMap()instead.- Specified by:
getFeatureImportancesin interfacePublic.FeatureImportancesOrBuilder
-
getFeatureImportancesMap
public Map<String,Double> getFeatureImportancesMap()
importances is a map of human readable model input field containing values that will be used to group together a subset of predictions and feature importance values for a given model_id and model_version
map<string, double> feature_importances = 3;- Specified by:
getFeatureImportancesMapin interfacePublic.FeatureImportancesOrBuilder
-
getFeatureImportancesOrDefault
public double getFeatureImportancesOrDefault(String key, double defaultValue)
importances is a map of human readable model input field containing values that will be used to group together a subset of predictions and feature importance values for a given model_id and model_version
map<string, double> feature_importances = 3;- Specified by:
getFeatureImportancesOrDefaultin interfacePublic.FeatureImportancesOrBuilder
-
getFeatureImportancesOrThrow
public double getFeatureImportancesOrThrow(String key)
importances is a map of human readable model input field containing values that will be used to group together a subset of predictions and feature importance values for a given model_id and model_version
map<string, double> feature_importances = 3;- Specified by:
getFeatureImportancesOrThrowin interfacePublic.FeatureImportancesOrBuilder
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessageV3
-
writeTo
public void writeTo(com.google.protobuf.CodedOutputStream output) throws IOException- Specified by:
writeToin interfacecom.google.protobuf.MessageLite- Overrides:
writeToin classcom.google.protobuf.GeneratedMessageV3- Throws:
IOException
-
getSerializedSize
public int getSerializedSize()
- Specified by:
getSerializedSizein interfacecom.google.protobuf.MessageLite- Overrides:
getSerializedSizein classcom.google.protobuf.GeneratedMessageV3
-
equals
public boolean equals(Object obj)
- Specified by:
equalsin interfacecom.google.protobuf.Message- Overrides:
equalsin classcom.google.protobuf.AbstractMessage
-
hashCode
public int hashCode()
- Specified by:
hashCodein interfacecom.google.protobuf.Message- Overrides:
hashCodein classcom.google.protobuf.AbstractMessage
-
parseFrom
public static Public.FeatureImportances parseFrom(ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.FeatureImportances parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.FeatureImportances parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.FeatureImportances parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.FeatureImportances parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.FeatureImportances parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.FeatureImportances parseFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.FeatureImportances parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.FeatureImportances parseDelimitedFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.FeatureImportances parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.FeatureImportances parseFrom(com.google.protobuf.CodedInputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.FeatureImportances parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
newBuilderForType
public Public.FeatureImportances.Builder newBuilderForType()
- Specified by:
newBuilderForTypein interfacecom.google.protobuf.Message- Specified by:
newBuilderForTypein interfacecom.google.protobuf.MessageLite
-
newBuilder
public static Public.FeatureImportances.Builder newBuilder()
-
newBuilder
public static Public.FeatureImportances.Builder newBuilder(Public.FeatureImportances prototype)
-
toBuilder
public Public.FeatureImportances.Builder toBuilder()
- Specified by:
toBuilderin interfacecom.google.protobuf.Message- Specified by:
toBuilderin interfacecom.google.protobuf.MessageLite
-
newBuilderForType
protected Public.FeatureImportances.Builder newBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)
- Specified by:
newBuilderForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstance
public static Public.FeatureImportances getDefaultInstance()
-
parser
public static com.google.protobuf.Parser<Public.FeatureImportances> parser()
-
getParserForType
public com.google.protobuf.Parser<Public.FeatureImportances> getParserForType()
- Specified by:
getParserForTypein interfacecom.google.protobuf.Message- Specified by:
getParserForTypein interfacecom.google.protobuf.MessageLite- Overrides:
getParserForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstanceForType
public Public.FeatureImportances getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
-