Package com.arize.protocol
Class Public.PredictionInstanceSegmentationPolygon
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite
-
- com.google.protobuf.AbstractMessage
-
- com.google.protobuf.GeneratedMessageV3
-
- com.arize.protocol.Public.PredictionInstanceSegmentationPolygon
-
- All Implemented Interfaces:
Public.PredictionInstanceSegmentationPolygonOrBuilder,com.google.protobuf.Message,com.google.protobuf.MessageLite,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,Serializable
- Enclosing class:
- Public
public static final class Public.PredictionInstanceSegmentationPolygon extends com.google.protobuf.GeneratedMessageV3 implements Public.PredictionInstanceSegmentationPolygonOrBuilder
PredictionInstanceSegmentationPolygon contains the coordinates to define the polygon shape, the category of the polygon, the score of the polygon, and the absolute coordinates of the bounding box that contains the polygon. Coordiantes and category are required while score and bbox_coordinates are optional.
Protobuf typepublic.PredictionInstanceSegmentationPolygon- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classPublic.PredictionInstanceSegmentationPolygon.BuilderPredictionInstanceSegmentationPolygon contains the coordinates to define the polygon shape, the category of the polygon, the score of the polygon, and the absolute coordinates of the bounding box that contains the polygon.-
Nested classes/interfaces inherited from class com.google.protobuf.GeneratedMessageV3
com.google.protobuf.GeneratedMessageV3.BuilderParent, com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>,BuilderT extends com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT,BuilderT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessageOrBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.FieldAccessorTable, com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter
-
-
Field Summary
Fields Modifier and Type Field Description static intBBOX_COORDINATES_FIELD_NUMBERstatic intCATEGORY_FIELD_NUMBERstatic intCOORDINATES_FIELD_NUMBERstatic intSCORE_FIELD_NUMBER
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(Object obj)doublegetBboxCoordinates(int index)format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixelsintgetBboxCoordinatesCount()format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixelsList<Double>getBboxCoordinatesList()format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixelsStringgetCategory()string category = 3;com.google.protobuf.ByteStringgetCategoryBytes()string category = 3;doublegetCoordinates(int index)format (x,y,x,y...intgetCoordinatesCount()format (x,y,x,y...List<Double>getCoordinatesList()format (x,y,x,y...static Public.PredictionInstanceSegmentationPolygongetDefaultInstance()Public.PredictionInstanceSegmentationPolygongetDefaultInstanceForType()static com.google.protobuf.Descriptors.DescriptorgetDescriptor()com.google.protobuf.Parser<Public.PredictionInstanceSegmentationPolygon>getParserForType()com.google.protobuf.DoubleValuegetScore().google.protobuf.DoubleValue score = 4;com.google.protobuf.DoubleValueOrBuildergetScoreOrBuilder().google.protobuf.DoubleValue score = 4;intgetSerializedSize()com.google.protobuf.UnknownFieldSetgetUnknownFields()inthashCode()booleanhasScore().google.protobuf.DoubleValue score = 4;protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTableinternalGetFieldAccessorTable()booleanisInitialized()static Public.PredictionInstanceSegmentationPolygon.BuildernewBuilder()static Public.PredictionInstanceSegmentationPolygon.BuildernewBuilder(Public.PredictionInstanceSegmentationPolygon prototype)Public.PredictionInstanceSegmentationPolygon.BuildernewBuilderForType()protected Public.PredictionInstanceSegmentationPolygon.BuildernewBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)protected ObjectnewInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)static Public.PredictionInstanceSegmentationPolygonparseDelimitedFrom(InputStream input)static Public.PredictionInstanceSegmentationPolygonparseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.PredictionInstanceSegmentationPolygonparseFrom(byte[] data)static Public.PredictionInstanceSegmentationPolygonparseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.PredictionInstanceSegmentationPolygonparseFrom(com.google.protobuf.ByteString data)static Public.PredictionInstanceSegmentationPolygonparseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.PredictionInstanceSegmentationPolygonparseFrom(com.google.protobuf.CodedInputStream input)static Public.PredictionInstanceSegmentationPolygonparseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.PredictionInstanceSegmentationPolygonparseFrom(InputStream input)static Public.PredictionInstanceSegmentationPolygonparseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.PredictionInstanceSegmentationPolygonparseFrom(ByteBuffer data)static Public.PredictionInstanceSegmentationPolygonparseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static com.google.protobuf.Parser<Public.PredictionInstanceSegmentationPolygon>parser()Public.PredictionInstanceSegmentationPolygon.BuildertoBuilder()voidwriteTo(com.google.protobuf.CodedOutputStream output)-
Methods inherited from class com.google.protobuf.GeneratedMessageV3
canUseUnsafe, computeStringSize, computeStringSizeNoTag, emptyBooleanList, emptyDoubleList, emptyFloatList, emptyIntList, emptyList, emptyLongList, getAllFields, getDescriptorForType, getField, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, isStringEmpty, makeExtensionsImmutable, makeMutableCopy, makeMutableCopy, mergeFromAndMakeImmutableInternal, mutableCopy, mutableCopy, mutableCopy, mutableCopy, mutableCopy, newBooleanList, newBuilderForType, newDoubleList, newFloatList, newIntList, newLongList, parseDelimitedWithIOException, parseDelimitedWithIOException, parseUnknownField, parseUnknownFieldProto3, parseWithIOException, parseWithIOException, parseWithIOException, parseWithIOException, serializeBooleanMapTo, serializeIntegerMapTo, serializeLongMapTo, serializeStringMapTo, writeReplace, writeString, writeStringNoTag
-
Methods inherited from class com.google.protobuf.AbstractMessage
findInitializationErrors, getInitializationErrorString, hashBoolean, hashEnum, hashEnumList, hashFields, hashLong, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite
addAll, addAll, checkByteStringIsUtf8, toByteArray, toByteString, writeDelimitedTo, writeTo
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
-
-
-
Field Detail
-
COORDINATES_FIELD_NUMBER
public static final int COORDINATES_FIELD_NUMBER
- See Also:
- Constant Field Values
-
BBOX_COORDINATES_FIELD_NUMBER
public static final int BBOX_COORDINATES_FIELD_NUMBER
- See Also:
- Constant Field Values
-
CATEGORY_FIELD_NUMBER
public static final int CATEGORY_FIELD_NUMBER
- See Also:
- Constant Field Values
-
SCORE_FIELD_NUMBER
public static final int SCORE_FIELD_NUMBER
- See Also:
- Constant Field Values
-
-
Method Detail
-
newInstance
protected Object newInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)
- Overrides:
newInstancein classcom.google.protobuf.GeneratedMessageV3
-
getUnknownFields
public final com.google.protobuf.UnknownFieldSet getUnknownFields()
- Specified by:
getUnknownFieldsin interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getUnknownFieldsin classcom.google.protobuf.GeneratedMessageV3
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessageV3
-
getCoordinatesList
public List<Double> getCoordinatesList()
format (x,y,x,y... of vertices)
repeated double coordinates = 1;- Specified by:
getCoordinatesListin interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder- Returns:
- A list containing the coordinates.
-
getCoordinatesCount
public int getCoordinatesCount()
format (x,y,x,y... of vertices)
repeated double coordinates = 1;- Specified by:
getCoordinatesCountin interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder- Returns:
- The count of coordinates.
-
getCoordinates
public double getCoordinates(int index)
format (x,y,x,y... of vertices)
repeated double coordinates = 1;- Specified by:
getCoordinatesin interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder- Parameters:
index- The index of the element to return.- Returns:
- The coordinates at the given index.
-
getBboxCoordinatesList
public List<Double> getBboxCoordinatesList()
format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixels
repeated double bbox_coordinates = 2;- Specified by:
getBboxCoordinatesListin interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder- Returns:
- A list containing the bboxCoordinates.
-
getBboxCoordinatesCount
public int getBboxCoordinatesCount()
format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixels
repeated double bbox_coordinates = 2;- Specified by:
getBboxCoordinatesCountin interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder- Returns:
- The count of bboxCoordinates.
-
getBboxCoordinates
public double getBboxCoordinates(int index)
format (top-left-x, top-left-y, bottom-right-x, bottom-right-y) in pixels
repeated double bbox_coordinates = 2;- Specified by:
getBboxCoordinatesin interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder- Parameters:
index- The index of the element to return.- Returns:
- The bboxCoordinates at the given index.
-
getCategory
public String getCategory()
string category = 3;- Specified by:
getCategoryin interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder- Returns:
- The category.
-
getCategoryBytes
public com.google.protobuf.ByteString getCategoryBytes()
string category = 3;- Specified by:
getCategoryBytesin interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder- Returns:
- The bytes for category.
-
hasScore
public boolean hasScore()
.google.protobuf.DoubleValue score = 4;- Specified by:
hasScorein interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder- Returns:
- Whether the score field is set.
-
getScore
public com.google.protobuf.DoubleValue getScore()
.google.protobuf.DoubleValue score = 4;- Specified by:
getScorein interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder- Returns:
- The score.
-
getScoreOrBuilder
public com.google.protobuf.DoubleValueOrBuilder getScoreOrBuilder()
.google.protobuf.DoubleValue score = 4;- Specified by:
getScoreOrBuilderin interfacePublic.PredictionInstanceSegmentationPolygonOrBuilder
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessageV3
-
writeTo
public void writeTo(com.google.protobuf.CodedOutputStream output) throws IOException- Specified by:
writeToin interfacecom.google.protobuf.MessageLite- Overrides:
writeToin classcom.google.protobuf.GeneratedMessageV3- Throws:
IOException
-
getSerializedSize
public int getSerializedSize()
- Specified by:
getSerializedSizein interfacecom.google.protobuf.MessageLite- Overrides:
getSerializedSizein classcom.google.protobuf.GeneratedMessageV3
-
equals
public boolean equals(Object obj)
- Specified by:
equalsin interfacecom.google.protobuf.Message- Overrides:
equalsin classcom.google.protobuf.AbstractMessage
-
hashCode
public int hashCode()
- Specified by:
hashCodein interfacecom.google.protobuf.Message- Overrides:
hashCodein classcom.google.protobuf.AbstractMessage
-
parseFrom
public static Public.PredictionInstanceSegmentationPolygon parseFrom(ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.PredictionInstanceSegmentationPolygon parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.PredictionInstanceSegmentationPolygon parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.PredictionInstanceSegmentationPolygon parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.PredictionInstanceSegmentationPolygon parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.PredictionInstanceSegmentationPolygon parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.PredictionInstanceSegmentationPolygon parseFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.PredictionInstanceSegmentationPolygon parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.PredictionInstanceSegmentationPolygon parseDelimitedFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.PredictionInstanceSegmentationPolygon parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.PredictionInstanceSegmentationPolygon parseFrom(com.google.protobuf.CodedInputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.PredictionInstanceSegmentationPolygon parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
newBuilderForType
public Public.PredictionInstanceSegmentationPolygon.Builder newBuilderForType()
- Specified by:
newBuilderForTypein interfacecom.google.protobuf.Message- Specified by:
newBuilderForTypein interfacecom.google.protobuf.MessageLite
-
newBuilder
public static Public.PredictionInstanceSegmentationPolygon.Builder newBuilder()
-
newBuilder
public static Public.PredictionInstanceSegmentationPolygon.Builder newBuilder(Public.PredictionInstanceSegmentationPolygon prototype)
-
toBuilder
public Public.PredictionInstanceSegmentationPolygon.Builder toBuilder()
- Specified by:
toBuilderin interfacecom.google.protobuf.Message- Specified by:
toBuilderin interfacecom.google.protobuf.MessageLite
-
newBuilderForType
protected Public.PredictionInstanceSegmentationPolygon.Builder newBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)
- Specified by:
newBuilderForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstance
public static Public.PredictionInstanceSegmentationPolygon getDefaultInstance()
-
parser
public static com.google.protobuf.Parser<Public.PredictionInstanceSegmentationPolygon> parser()
-
getParserForType
public com.google.protobuf.Parser<Public.PredictionInstanceSegmentationPolygon> getParserForType()
- Specified by:
getParserForTypein interfacecom.google.protobuf.Message- Specified by:
getParserForTypein interfacecom.google.protobuf.MessageLite- Overrides:
getParserForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstanceForType
public Public.PredictionInstanceSegmentationPolygon getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
-