Package com.arize.protocol
Enum Public.Schema.ModelType
- java.lang.Object
-
- java.lang.Enum<Public.Schema.ModelType>
-
- com.arize.protocol.Public.Schema.ModelType
-
- All Implemented Interfaces:
com.google.protobuf.Internal.EnumLite,com.google.protobuf.ProtocolMessageEnum,Serializable,Comparable<Public.Schema.ModelType>
- Enclosing class:
- Public.Schema
public static enum Public.Schema.ModelType extends Enum<Public.Schema.ModelType> implements com.google.protobuf.ProtocolMessageEnum
Protobuf enumpublic.Schema.ModelType
-
-
Enum Constant Summary
Enum Constants Enum Constant Description BINARYBINARY = 1;CATEGORICALCATEGORICAL = 3;GENERATIVE_LLMGENERATIVE_LLM = 7;MULTI_CLASSMULTI_CLASS = 8;NUMERICNUMERIC = 2;OBJECT_DETECTIONOBJECT_DETECTION = 6;RANKINGRANKING = 5;SCORE_CATEGORICALSCORE_CATEGORICAL = 4;UNKNOWN_MODELTYPEUNKNOWN_MODELTYPE = 0;UNRECOGNIZED
-
Field Summary
Fields Modifier and Type Field Description static intBINARY_VALUEBINARY = 1;static intCATEGORICAL_VALUECATEGORICAL = 3;static intGENERATIVE_LLM_VALUEGENERATIVE_LLM = 7;static intMULTI_CLASS_VALUEMULTI_CLASS = 8;static intNUMERIC_VALUENUMERIC = 2;static intOBJECT_DETECTION_VALUEOBJECT_DETECTION = 6;static intRANKING_VALUERANKING = 5;static intSCORE_CATEGORICAL_VALUESCORE_CATEGORICAL = 4;static intUNKNOWN_MODELTYPE_VALUEUNKNOWN_MODELTYPE = 0;
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Deprecated Methods Modifier and Type Method Description static Public.Schema.ModelTypeforNumber(int value)static com.google.protobuf.Descriptors.EnumDescriptorgetDescriptor()com.google.protobuf.Descriptors.EnumDescriptorgetDescriptorForType()intgetNumber()com.google.protobuf.Descriptors.EnumValueDescriptorgetValueDescriptor()static com.google.protobuf.Internal.EnumLiteMap<Public.Schema.ModelType>internalGetValueMap()static Public.Schema.ModelTypevalueOf(int value)Deprecated.static Public.Schema.ModelTypevalueOf(com.google.protobuf.Descriptors.EnumValueDescriptor desc)Returns the enum constant of this type with the specified name.static Public.Schema.ModelTypevalueOf(String name)Returns the enum constant of this type with the specified name.static Public.Schema.ModelType[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
UNKNOWN_MODELTYPE
public static final Public.Schema.ModelType UNKNOWN_MODELTYPE
UNKNOWN_MODELTYPE = 0;
-
BINARY
public static final Public.Schema.ModelType BINARY
BINARY = 1;
-
NUMERIC
public static final Public.Schema.ModelType NUMERIC
NUMERIC = 2;
-
CATEGORICAL
public static final Public.Schema.ModelType CATEGORICAL
CATEGORICAL = 3;
-
SCORE_CATEGORICAL
public static final Public.Schema.ModelType SCORE_CATEGORICAL
SCORE_CATEGORICAL = 4;
-
RANKING
public static final Public.Schema.ModelType RANKING
RANKING = 5;
-
OBJECT_DETECTION
public static final Public.Schema.ModelType OBJECT_DETECTION
OBJECT_DETECTION = 6;
-
GENERATIVE_LLM
public static final Public.Schema.ModelType GENERATIVE_LLM
GENERATIVE_LLM = 7;
-
MULTI_CLASS
public static final Public.Schema.ModelType MULTI_CLASS
MULTI_CLASS = 8;
-
UNRECOGNIZED
public static final Public.Schema.ModelType UNRECOGNIZED
-
-
Field Detail
-
UNKNOWN_MODELTYPE_VALUE
public static final int UNKNOWN_MODELTYPE_VALUE
UNKNOWN_MODELTYPE = 0;- See Also:
- Constant Field Values
-
BINARY_VALUE
public static final int BINARY_VALUE
BINARY = 1;- See Also:
- Constant Field Values
-
NUMERIC_VALUE
public static final int NUMERIC_VALUE
NUMERIC = 2;- See Also:
- Constant Field Values
-
CATEGORICAL_VALUE
public static final int CATEGORICAL_VALUE
CATEGORICAL = 3;- See Also:
- Constant Field Values
-
SCORE_CATEGORICAL_VALUE
public static final int SCORE_CATEGORICAL_VALUE
SCORE_CATEGORICAL = 4;- See Also:
- Constant Field Values
-
RANKING_VALUE
public static final int RANKING_VALUE
RANKING = 5;- See Also:
- Constant Field Values
-
OBJECT_DETECTION_VALUE
public static final int OBJECT_DETECTION_VALUE
OBJECT_DETECTION = 6;- See Also:
- Constant Field Values
-
GENERATIVE_LLM_VALUE
public static final int GENERATIVE_LLM_VALUE
GENERATIVE_LLM = 7;- See Also:
- Constant Field Values
-
MULTI_CLASS_VALUE
public static final int MULTI_CLASS_VALUE
MULTI_CLASS = 8;- See Also:
- Constant Field Values
-
-
Method Detail
-
values
public static Public.Schema.ModelType[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (Public.Schema.ModelType c : Public.Schema.ModelType.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static Public.Schema.ModelType valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
getNumber
public final int getNumber()
- Specified by:
getNumberin interfacecom.google.protobuf.Internal.EnumLite- Specified by:
getNumberin interfacecom.google.protobuf.ProtocolMessageEnum
-
valueOf
@Deprecated public static Public.Schema.ModelType valueOf(int value)
Deprecated.Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
value- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
forNumber
public static Public.Schema.ModelType forNumber(int value)
- Parameters:
value- The numeric wire value of the corresponding enum entry.- Returns:
- The enum associated with the given numeric wire value.
-
internalGetValueMap
public static com.google.protobuf.Internal.EnumLiteMap<Public.Schema.ModelType> internalGetValueMap()
-
getValueDescriptor
public final com.google.protobuf.Descriptors.EnumValueDescriptor getValueDescriptor()
- Specified by:
getValueDescriptorin interfacecom.google.protobuf.ProtocolMessageEnum
-
getDescriptorForType
public final com.google.protobuf.Descriptors.EnumDescriptor getDescriptorForType()
- Specified by:
getDescriptorForTypein interfacecom.google.protobuf.ProtocolMessageEnum
-
getDescriptor
public static final com.google.protobuf.Descriptors.EnumDescriptor getDescriptor()
-
valueOf
public static Public.Schema.ModelType valueOf(com.google.protobuf.Descriptors.EnumValueDescriptor desc)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
desc- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
-