Package com.arize.protocol
Class Public.SemanticSegmentationPolygon
- java.lang.Object
-
- com.google.protobuf.AbstractMessageLite
-
- com.google.protobuf.AbstractMessage
-
- com.google.protobuf.GeneratedMessageV3
-
- com.arize.protocol.Public.SemanticSegmentationPolygon
-
- All Implemented Interfaces:
Public.SemanticSegmentationPolygonOrBuilder,com.google.protobuf.Message,com.google.protobuf.MessageLite,com.google.protobuf.MessageLiteOrBuilder,com.google.protobuf.MessageOrBuilder,Serializable
- Enclosing class:
- Public
public static final class Public.SemanticSegmentationPolygon extends com.google.protobuf.GeneratedMessageV3 implements Public.SemanticSegmentationPolygonOrBuilder
SemanticSegmentationPolygon contains the coordinates to define the polygon shape as well as the category of the polygon. Both coordinates and category are required.
Protobuf typepublic.SemanticSegmentationPolygon- See Also:
- Serialized Form
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classPublic.SemanticSegmentationPolygon.BuilderSemanticSegmentationPolygon contains the coordinates to define the polygon shape as well as the category of the polygon.-
Nested classes/interfaces inherited from class com.google.protobuf.GeneratedMessageV3
com.google.protobuf.GeneratedMessageV3.BuilderParent, com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>,BuilderT extends com.google.protobuf.GeneratedMessageV3.ExtendableBuilder<MessageT,BuilderT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.ExtendableMessageOrBuilder<MessageT extends com.google.protobuf.GeneratedMessageV3.ExtendableMessage<MessageT>>, com.google.protobuf.GeneratedMessageV3.FieldAccessorTable, com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter
-
-
Field Summary
Fields Modifier and Type Field Description static intCATEGORY_FIELD_NUMBERstatic intCOORDINATES_FIELD_NUMBER
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanequals(Object obj)StringgetCategory()string category = 2;com.google.protobuf.ByteStringgetCategoryBytes()string category = 2;doublegetCoordinates(int index)format (x,y,x,y...intgetCoordinatesCount()format (x,y,x,y...List<Double>getCoordinatesList()format (x,y,x,y...static Public.SemanticSegmentationPolygongetDefaultInstance()Public.SemanticSegmentationPolygongetDefaultInstanceForType()static com.google.protobuf.Descriptors.DescriptorgetDescriptor()com.google.protobuf.Parser<Public.SemanticSegmentationPolygon>getParserForType()intgetSerializedSize()com.google.protobuf.UnknownFieldSetgetUnknownFields()inthashCode()protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTableinternalGetFieldAccessorTable()booleanisInitialized()static Public.SemanticSegmentationPolygon.BuildernewBuilder()static Public.SemanticSegmentationPolygon.BuildernewBuilder(Public.SemanticSegmentationPolygon prototype)Public.SemanticSegmentationPolygon.BuildernewBuilderForType()protected Public.SemanticSegmentationPolygon.BuildernewBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)protected ObjectnewInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)static Public.SemanticSegmentationPolygonparseDelimitedFrom(InputStream input)static Public.SemanticSegmentationPolygonparseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.SemanticSegmentationPolygonparseFrom(byte[] data)static Public.SemanticSegmentationPolygonparseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.SemanticSegmentationPolygonparseFrom(com.google.protobuf.ByteString data)static Public.SemanticSegmentationPolygonparseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.SemanticSegmentationPolygonparseFrom(com.google.protobuf.CodedInputStream input)static Public.SemanticSegmentationPolygonparseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.SemanticSegmentationPolygonparseFrom(InputStream input)static Public.SemanticSegmentationPolygonparseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static Public.SemanticSegmentationPolygonparseFrom(ByteBuffer data)static Public.SemanticSegmentationPolygonparseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry)static com.google.protobuf.Parser<Public.SemanticSegmentationPolygon>parser()Public.SemanticSegmentationPolygon.BuildertoBuilder()voidwriteTo(com.google.protobuf.CodedOutputStream output)-
Methods inherited from class com.google.protobuf.GeneratedMessageV3
canUseUnsafe, computeStringSize, computeStringSizeNoTag, emptyBooleanList, emptyDoubleList, emptyFloatList, emptyIntList, emptyList, emptyLongList, getAllFields, getDescriptorForType, getField, getOneofFieldDescriptor, getRepeatedField, getRepeatedFieldCount, hasField, hasOneof, internalGetMapField, internalGetMapFieldReflection, isStringEmpty, makeExtensionsImmutable, makeMutableCopy, makeMutableCopy, mergeFromAndMakeImmutableInternal, mutableCopy, mutableCopy, mutableCopy, mutableCopy, mutableCopy, newBooleanList, newBuilderForType, newDoubleList, newFloatList, newIntList, newLongList, parseDelimitedWithIOException, parseDelimitedWithIOException, parseUnknownField, parseUnknownFieldProto3, parseWithIOException, parseWithIOException, parseWithIOException, parseWithIOException, serializeBooleanMapTo, serializeIntegerMapTo, serializeLongMapTo, serializeStringMapTo, writeReplace, writeString, writeStringNoTag
-
Methods inherited from class com.google.protobuf.AbstractMessage
findInitializationErrors, getInitializationErrorString, hashBoolean, hashEnum, hashEnumList, hashFields, hashLong, toString
-
Methods inherited from class com.google.protobuf.AbstractMessageLite
addAll, addAll, checkByteStringIsUtf8, toByteArray, toByteString, writeDelimitedTo, writeTo
-
Methods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, wait
-
-
-
-
Field Detail
-
COORDINATES_FIELD_NUMBER
public static final int COORDINATES_FIELD_NUMBER
- See Also:
- Constant Field Values
-
CATEGORY_FIELD_NUMBER
public static final int CATEGORY_FIELD_NUMBER
- See Also:
- Constant Field Values
-
-
Method Detail
-
newInstance
protected Object newInstance(com.google.protobuf.GeneratedMessageV3.UnusedPrivateParameter unused)
- Overrides:
newInstancein classcom.google.protobuf.GeneratedMessageV3
-
getUnknownFields
public final com.google.protobuf.UnknownFieldSet getUnknownFields()
- Specified by:
getUnknownFieldsin interfacecom.google.protobuf.MessageOrBuilder- Overrides:
getUnknownFieldsin classcom.google.protobuf.GeneratedMessageV3
-
getDescriptor
public static final com.google.protobuf.Descriptors.Descriptor getDescriptor()
-
internalGetFieldAccessorTable
protected com.google.protobuf.GeneratedMessageV3.FieldAccessorTable internalGetFieldAccessorTable()
- Specified by:
internalGetFieldAccessorTablein classcom.google.protobuf.GeneratedMessageV3
-
getCoordinatesList
public List<Double> getCoordinatesList()
format (x,y,x,y... of vertices)
repeated double coordinates = 1;- Specified by:
getCoordinatesListin interfacePublic.SemanticSegmentationPolygonOrBuilder- Returns:
- A list containing the coordinates.
-
getCoordinatesCount
public int getCoordinatesCount()
format (x,y,x,y... of vertices)
repeated double coordinates = 1;- Specified by:
getCoordinatesCountin interfacePublic.SemanticSegmentationPolygonOrBuilder- Returns:
- The count of coordinates.
-
getCoordinates
public double getCoordinates(int index)
format (x,y,x,y... of vertices)
repeated double coordinates = 1;- Specified by:
getCoordinatesin interfacePublic.SemanticSegmentationPolygonOrBuilder- Parameters:
index- The index of the element to return.- Returns:
- The coordinates at the given index.
-
getCategory
public String getCategory()
string category = 2;- Specified by:
getCategoryin interfacePublic.SemanticSegmentationPolygonOrBuilder- Returns:
- The category.
-
getCategoryBytes
public com.google.protobuf.ByteString getCategoryBytes()
string category = 2;- Specified by:
getCategoryBytesin interfacePublic.SemanticSegmentationPolygonOrBuilder- Returns:
- The bytes for category.
-
isInitialized
public final boolean isInitialized()
- Specified by:
isInitializedin interfacecom.google.protobuf.MessageLiteOrBuilder- Overrides:
isInitializedin classcom.google.protobuf.GeneratedMessageV3
-
writeTo
public void writeTo(com.google.protobuf.CodedOutputStream output) throws IOException- Specified by:
writeToin interfacecom.google.protobuf.MessageLite- Overrides:
writeToin classcom.google.protobuf.GeneratedMessageV3- Throws:
IOException
-
getSerializedSize
public int getSerializedSize()
- Specified by:
getSerializedSizein interfacecom.google.protobuf.MessageLite- Overrides:
getSerializedSizein classcom.google.protobuf.GeneratedMessageV3
-
equals
public boolean equals(Object obj)
- Specified by:
equalsin interfacecom.google.protobuf.Message- Overrides:
equalsin classcom.google.protobuf.AbstractMessage
-
hashCode
public int hashCode()
- Specified by:
hashCodein interfacecom.google.protobuf.Message- Overrides:
hashCodein classcom.google.protobuf.AbstractMessage
-
parseFrom
public static Public.SemanticSegmentationPolygon parseFrom(ByteBuffer data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.SemanticSegmentationPolygon parseFrom(ByteBuffer data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.SemanticSegmentationPolygon parseFrom(com.google.protobuf.ByteString data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.SemanticSegmentationPolygon parseFrom(com.google.protobuf.ByteString data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.SemanticSegmentationPolygon parseFrom(byte[] data) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.SemanticSegmentationPolygon parseFrom(byte[] data, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws com.google.protobuf.InvalidProtocolBufferException
- Throws:
com.google.protobuf.InvalidProtocolBufferException
-
parseFrom
public static Public.SemanticSegmentationPolygon parseFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.SemanticSegmentationPolygon parseFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.SemanticSegmentationPolygon parseDelimitedFrom(InputStream input) throws IOException
- Throws:
IOException
-
parseDelimitedFrom
public static Public.SemanticSegmentationPolygon parseDelimitedFrom(InputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.SemanticSegmentationPolygon parseFrom(com.google.protobuf.CodedInputStream input) throws IOException
- Throws:
IOException
-
parseFrom
public static Public.SemanticSegmentationPolygon parseFrom(com.google.protobuf.CodedInputStream input, com.google.protobuf.ExtensionRegistryLite extensionRegistry) throws IOException
- Throws:
IOException
-
newBuilderForType
public Public.SemanticSegmentationPolygon.Builder newBuilderForType()
- Specified by:
newBuilderForTypein interfacecom.google.protobuf.Message- Specified by:
newBuilderForTypein interfacecom.google.protobuf.MessageLite
-
newBuilder
public static Public.SemanticSegmentationPolygon.Builder newBuilder()
-
newBuilder
public static Public.SemanticSegmentationPolygon.Builder newBuilder(Public.SemanticSegmentationPolygon prototype)
-
toBuilder
public Public.SemanticSegmentationPolygon.Builder toBuilder()
- Specified by:
toBuilderin interfacecom.google.protobuf.Message- Specified by:
toBuilderin interfacecom.google.protobuf.MessageLite
-
newBuilderForType
protected Public.SemanticSegmentationPolygon.Builder newBuilderForType(com.google.protobuf.GeneratedMessageV3.BuilderParent parent)
- Specified by:
newBuilderForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstance
public static Public.SemanticSegmentationPolygon getDefaultInstance()
-
parser
public static com.google.protobuf.Parser<Public.SemanticSegmentationPolygon> parser()
-
getParserForType
public com.google.protobuf.Parser<Public.SemanticSegmentationPolygon> getParserForType()
- Specified by:
getParserForTypein interfacecom.google.protobuf.Message- Specified by:
getParserForTypein interfacecom.google.protobuf.MessageLite- Overrides:
getParserForTypein classcom.google.protobuf.GeneratedMessageV3
-
getDefaultInstanceForType
public Public.SemanticSegmentationPolygon getDefaultInstanceForType()
- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageLiteOrBuilder- Specified by:
getDefaultInstanceForTypein interfacecom.google.protobuf.MessageOrBuilder
-
-